package PAR::StrippedPARL::Dynamic;
use 5.006;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut




__DATA__
M?T5,1@$!`0````````````(``P`!````\)P$"#0```!LL@```````#0`(``(
M`"@`'``;``8````T````-(`$"#2`!`@``0````$```4````$`````P```#0!
M```T@00(-($$"!,````3````!`````$````!``````````"`!`@`@`0(P*P`
M`,"L```%`````!````$```#DK@``Y#X%".0^!0AP`@``S!(```8`````$```
M`@```/BN``#X/@4(^#X%"/@```#X````!@````0````$````2`$``$B!!`A(
M@00(1````$0````$````!````%'E=&0```````````````````````````8`
M```$````4N5T9.2N``#D/@4(Y#X%"!P!```<`0``!`````$````O;&EB+VQD
M+6QI;G5X+G-O+C(```0````0`````0```$=.50```````@````8````/````
M!````!0````#````1TY5`&6Z'&])F^V!>O^FVP:@&U<%!DG(80```'0````+
M``````````````!$`````````$@```!'`````````$L```!;````/@```#D`
M``!,`````P```%D`````````,0```&````!6````:P```&T```!H````!```
M`"P``````````````"H```!D````'@``````````````90```$D```!F````
M"0````````!3````<P````````!.`````````!\`````````<0````````!2
M````;P``````````````9P```"@```!0````.@``````````````<````#4`
M``!!````1@``````````````$@`````````_```````````````C````````
M`!P````P````#````#(````I````50``````````````7````%$````\````
M7P```$T````[````-`````````!`````````````````````5P```&X`````
M````10```%X```!#````/0```"<````!````````````````````````````
M`````````````````````````````````````````````$\`````````````
M```````````````````````/````%````&$`````````````````````````
M$P``````````````$0`````````9`````````````````````````%H`````
M````6`````````!I```````````````0```````````````7````&P``````
M```F````:@```"0````(`````````"\````E````#@```!T`````````8@``
M`"$`````````&@````T````*``````````````!"`````````#,````N````
M`````'(```!=``````````````!*````!P``````````````;```````````
M`````````````````````````"(``````````````!@`````````-@``````
M```K`````````````````````````!8````&````%0````````!4````````
M``4```````````````````!C````-P````(````@````+0```#@````E````
M3P````@````(`````!`0!"5`!("H$0`!HH9!J$````)+*`0I.*(R1XH$#(A/
M````40```````````````````%0```!6````5P````````!8````60``````
M``!:````6P```%P`````````70```````````````````%X```!A````````
M``````!B````9````&4```!G`````````&D```!L`````````&X```!O````
M<````'$`````````R-6R<5GH[>SF_S"BSMY'+:/@^TGJT^\.I]VC:R_%F[;;
MS>.>A_F<@6L)0]8-.I<+Q8D%D`T4XIXA_^0.L@&+;\2YG$!K?YI\?ZF<FV[%
MWQ_9<5@<N^.2?-1DU'RM2^/`,F+;[>&G`@IFK\QF8!;)67OP2FOB1\8!0T75
M[$?L,SI]08[%P^4_+/+;TQWZH6Q@N8WQ#@````````````````````#X`@``
M```````````2````L0``````````````$@```(T#`````````````!(```!X
M`P`````````````2````H0$`````````````$@```+T#`````````````!(`
M``!Z`@`````````````2````$0``````````````(````"``````````````
M`"````!^`P`````````````2````C0$`````````````$@```-X#````````
M`````!(```!N`0`````````````2````@`$`````````````$@```"\#````
M`````````!(````)`P`````````````2````+`(`````````````$@```/T`
M`````````````!(````<`@`````````````2````H@,`````````````$@``
M`,H!`````````````!(```!(!``````````````2````#00`````````````
M$@```-<"`````````````!(````1`P`````````````2````F`(`````````
M````$@```.H!`````````````!(```"F`0`````````````2````-0(`````
M````````$@```,L#`````````````!(````Z!``````````````2````+P$`
M````````````$@```-8#`````````````!(````T```````````````2````
MZ`,`````````````$@```%T!`````````````!(```#(```````````````2
M````&@0`````````````$@```+8#`````````````!(````&!```````````
M```2````FP,`````````````$@```'$#`````````````!(````7!0``````
M```````2````00$`````````````$@```/8#`````````````!(```!<`@``
M```````````2````5P,`````````````$@```.L"`````````````!(```!.
M`@`````````````2````J0,`````````````$@```)$"`````````````!(`
M``"K`0`````````````2````8`,`````````````$@```+`#````````````
M`!(```"4`P`````````````2````[```````````````$@```$(`````````
M`````!(```#]`P`````````````2````,@0`````````````$@```-<`````
M`````````!(```#^`0`````````````2````A0(`````````````$@```%`!
M`````````````!(````D!``````````````2````A@,`````````````$@``
M`$8#`````````````!(```#Q`@`````````````2````'0$`````````````
M$@```$,"`````````````!(```!4```````````````2````V`$`````````
M````$@```&,``````````````!(```!!!``````````````2````CP``````
M````````$@```$X#`````````````!(```!!`P`````````````2````>```
M````````````$@````L!`````````````!(```"W`0``5)@$"``````2````
MN`0``"#.!`@$````$0`0`($%``#@T`0(VEL``!$`$`"+!0``T+T$"/4)```2
M``X`MP4``""V!`B5`0``$@`.`+($``#\S00(`````!(`#P!<!```8$$%"`0`
M```A`!D`B@0```"S!`@,````$@`.`%`%``!PS00(6@```!(`#@"@````))H$
M"``````2````.P4``$!!!0@`````$``8`#T%``!`004(`````"``&`!;!```
M8$$%"`0````A`!D`J`0``&#-!`@%````$@`.`*H%``"PNP0((`(``!(`#@#5
M!```H*L$"$0````2``X`6@0``&!!!0@$````$0`9`%4$``"0N00((`(``!(`
M#@`%!0``P+<$"!\````2``X`(`4```"Y!`B&````$@`.`'D$``!4004(````
M`!``\?^%!```L%$%"``````0`/'_OP0``-#'!`B4!```$@`.`"`#```DS@0(
M!````!$`$`!!!0``\)P$"``````2``X`XP0``#"R!`C$````$@`.`/D$``#@
MMP0(&P$``!(`#@`L!0``4$$%"`0````1`!@`:@(``!2:!`@`````$@```)L$
M``"PG00(/@```!(`#@!R!```5$$%"``````0`/'_?`4``$Q!!0@$````$0`8
M`&`%```PK00(7````!(`#@!(!0``<,P$"#X````2``X`HP(``&1!!0@3````
M$0`9`)@%``#PM`0(*`$``!(`#@!*!0``I)<$"``````2``P``&QI8G!E<FPN
M<V\N-2XQ,`!?7V=M;VY?<W1A<G1?7P!?2G9?4F5G:7-T97)#;&%S<V5S`%!E
M<FQ?<WES7W1E<FT`4&5R;%])<W1A=&)U9E]P='(`4&5R;%]S>7-?:6YI=#,`
M4&5R;%])97AI=%]F;&%G<U]P='(`4&5R;%]S879E7V1E<W1R=6-T;W)?>`!0
M97)L7TEC;VUP8W9?<'1R`%!E<FQ?871F;W)K7VQO8VL`4&5R;%])8W5R<W1A
M8VMI;F9O7W!T<@!P97)L7V-O;G-T<G5C=`!097)L7V-R;V%K7VYO8V]N=&5X
M=`!097)L7TEP87)S97)?<'1R`%!E<FQ?879?<VAI9G0`4&5R;%]S=E\R<'9?
M9FQA9W,`4&5R;%])=&]P7V5N=E]P='(`4&5R;%])=&%I;G1E9%]P='(`4&5R
M;%]S=E]S971P=FX`4&5R;%]N97=35G!V`%!E<FQ?;F5W6%-?9FQA9W,`4&5R
M;%]):6Y?979A;%]P='(`4&5R;%]);W!?<'1R`%!E<FQ?265V86Q?<F]O=%]P
M='(`<&5R;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!0
M97)L7W-V7W-E='!V`%!E<FQ?1W1H<E]K97E?<'1R`%!E<FQ?1V1O7W5N9'5M
M<%]P='(`4&5R;%])<&5R;%]D97-T<G5C=%]L979E;%]P='(`4&5R;%]G=E]F
M971C:'!V`'!E<FQ?<G5N`%!E<FQ?9&]U;G=I;F0`4&5R;%]N97=84P!P97)L
M7V1E<W1R=6-T`%!E<FQ?879?9F5T8V@`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?
M<&%R<V4`4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?86QL;V,`4$Q?;65M;W)Y
M7W=R87``;&EB9&PN<V\N,@!L:6)M+G-O+C8`;&EB<'1H<F5A9"YS;RXP`'!T
M:')E861?9V5T<W!E8VEF:6,`8VQO<V4`;W!E;C8T`%]?97)R;F]?;&]C871I
M;VX`;'-E96LV-`!R96%D`&QI8F,N<V\N-@!?24]?<W1D:6Y?=7-E9`!?7W)E
M9VES=&5R7V%T9F]R:P!E>&ET`'-T<FYC;7``7U]S=')D=7``8VQO<V5D:7(`
M7U]S=&%C:U]C:&M?9F%I;`!U;FQI;FL`;6MD:7(`<F5A;&QO8P!M96UC:'(`
M9V5T<&ED`'-T<G1O:P!S=')L96X`;65M<V5T`'-T<G-T<@!R;61I<@!M96UC
M<'D`7U]S=')N8W!Y7V-H:P!?7VQX<W1A=#8T`&]P96YD:7(`7U]X<W1A=#8T
M`%]?8W1Y<&5?8E]L;V,`9V5T=6ED`')E861L:6YK`&5X96-V<`!?7VUE;6-P
M>5]C:&L`<F5A9&1I<C8T`%]?<W!R:6YT9E]C:&L`;65M;6]V90!A8V-E<W,`
M<W1R8VUP`%]?;&EB8U]S=&%R=%]M86EN`%]?96YV:7)O;@!L:6)C<GEP="YS
M;RXQ`%]E9&%T80!?7V)S<U]S=&%R=`!?96YD`'!A<E]C=7)R96YT7V5X96,`
M<&%R7V)A<V5N86UE`%]?;&EB8U]C<W5?9FEN:0!?9G!?:'<`6%-?26YT97)N
M86QS7U!!4E]"3T]4`'!A<E]E;G9?8VQE86X`<&%R7V-U<G)E;G1?97AE8U]P
M<F]C`'!A<E]D:7)N86UE`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A
M<E]C;&5A;G5P`'-I>F5?;&]A9%]M95\R`%]?9&%T85]S=&%R=`!X<U]I;FET
M`%]?;&EB8U]C<W5?:6YI=`!84U]);G1E<FYA;'-?4$%27T-,14%24U1!0TL`
M;F%M95]L;V%D7VUE7S(`<&%R7VUK=&UP9&ER`'!A<E]S971U<%]L:6)P871H
M`'!A<E]F:6YD<')O9P!P87)?:6YI=%]E;G8`1TQ)0D-?,BXT`$=,24)#7S(N
M,P!'3$E"0U\R+C,N,@!'3$E"0U\R+C(`1TQ)0D-?,BXS+C0`1TQ)0D-?,BXP
M`````@````,``P````0``````````P````4```````8`!P`````````#````
M`P`$``(``@```````P````4``P````,````(```````%``,``P`#``,``P``
M``,````#``(````#``,````)``,``P```````P`#````````````!``#``,`
M!P```````````````P````,``P`````````!``$``0`!``$``P`!``$````!
M``$``P`!``$``0`#``$``0`!``$``0`!``$``0`!``$``0````$``0`!``$`
M`0````$``0`!``8`%@,``!````!P````%&EI#0``"0#$!0``$````!-I:0T`
M``@`S@4``!````!R&6D)```&`-@%```0````$FEI#0``!0#D!0``$````'09
M:0D```0`[@4``!`````0:6D-```#`/H%`````````0`"`,<"```0````````
M`!)I:0T```<`Y`4``!`````0:6D-```"`/H%````````\#\%"`8(``!@004(
M!5\``&1!!0@%<0```$`%"`<!```$0`4(!P(```A`!0@'`P``#$`%"`<$```0
M0`4(!P4``!1`!0@'!@``&$`%"`<'```<0`4(!T\``"!`!0@'"```)$`%"`<*
M```H0`4(!PL``"Q`!0@'#```,$`%"`<-```T0`4(!PX``#A`!0@'#P``/$`%
M"`<0``!`0`4(!Q$``$1`!0@'$@``2$`%"`<3``!,0`4(!Q0``%!`!0@'%0``
M5$`%"`<6``!80`4(!Q<``%Q`!0@'&```8$`%"`<9``!D0`4(!QH``&A`!0@'
M&P``;$`%"`<<``!P0`4(!QT``'1`!0@''@``>$`%"`<?``!\0`4(!R```(!`
M!0@'(0``A$`%"`<B``"(0`4(!R,``(Q`!0@':P``D$`%"`=8``"40`4(!R0`
M`)A`!0@')0``G$`%"`<F``"@0`4(!R<``*1`!0@'*```J$`%"`<I``"L0`4(
M!RH``+!`!0@'*P``M$`%"`<L``"X0`4(!RT``+Q`!0@'+@``P$`%"`<O``#$
M0`4(!S```,A`!0@',0``S$`%"`<R``#00`4(!S,``-1`!0@'-```V$`%"`<U
M``#<0`4(!S8``.!`!0@'-P``Y$`%"`<X``#H0`4(!SD``.Q`!0@'.@``\$`%
M"`<[``#T0`4(!SP``/A`!0@'/0``_$`%"`<^````004(!S\```1!!0@'0```
M"$$%"`=!```,004(!T(``!!!!0@'0P``%$$%"`=$```8004(!T4``!Q!!0@'
M1@``($$%"`='```D004(!T@``"A!!0@'20``+$$%"`=*```P004(!TL``#1!
M!0@'3```.$$%"`=-```\004(!TX``%6)Y5.#[`3H`````%N!PT2H``"+D_S_
M__^%TG0%Z)X```#HM04``.@`-@``6%O)P_\U^#\%"/\E_#\%"`````#_)0!`
M!0AH`````.G@_____R4$0`4(:`@```#IT/____\E"$`%"&@0````Z<#_____
M)0Q`!0AH&````.FP_____R400`4(:"````#IH/____\E%$`%"&@H````Z9#_
M____)1A`!0AH,````.F`_____R4<0`4(:#@```#I</____\E($`%"&A`````
MZ6#_____)21`!0AH2````.E0_____R4H0`4(:%````#I0/____\E+$`%"&A8
M````Z3#_____)3!`!0AH8````.D@_____R4T0`4(:&@```#I$/____\E.$`%
M"&AP````Z0#_____)3Q`!0AH>````.GP_O___R5`0`4(:(````#IX/[___\E
M1$`%"&B(````Z=#^____)4A`!0AHD````.G`_O___R5,0`4(:)@```#IL/[_
M__\E4$`%"&B@````Z:#^____)51`!0AHJ````.F0_O___R580`4(:+````#I
M@/[___\E7$`%"&BX````Z7#^____)6!`!0AHP````.E@_O___R5D0`4(:,@`
M``#I4/[___\E:$`%"&C0````Z4#^____)6Q`!0AHV````.DP_O___R5P0`4(
M:.````#I(/[___\E=$`%"&CH````Z1#^____)7A`!0AH\````.D`_O___R5\
M0`4(:/@```#I\/W___\E@$`%"&@``0``Z>#]____)81`!0AH"`$``.G0_?__
M_R6(0`4(:!`!``#IP/W___\EC$`%"&@8`0``Z;#]____)9!`!0AH(`$``.F@
M_?___R640`4(:"@!``#ID/W___\EF$`%"&@P`0``Z8#]____)9Q`!0AH.`$`
M`.EP_?___R6@0`4(:$`!``#I8/W___\EI$`%"&A(`0``Z5#]____):A`!0AH
M4`$``.E`_?___R6L0`4(:%@!``#I,/W___\EL$`%"&A@`0``Z2#]____);1`
M!0AH:`$``.D0_?___R6X0`4(:'`!``#I`/W___\EO$`%"&AX`0``Z?#\____
M)<!`!0AH@`$``.G@_/___R7$0`4(:(@!``#IT/S___\ER$`%"&B0`0``Z<#\
M____)<Q`!0AHF`$``.FP_/___R700`4(:*`!``#IH/S___\EU$`%"&BH`0``
MZ9#\____)=A`!0AHL`$``.F`_/___R7<0`4(:+@!``#I</S___\EX$`%"&C`
M`0``Z6#\____)>1`!0AHR`$``.E0_/___R7H0`4(:-`!``#I0/S___\E[$`%
M"&C8`0``Z3#\____)?!`!0AHX`$``.D@_/___R7T0`4(:.@!``#I$/S___\E
M^$`%"&CP`0``Z0#\____)?Q`!0AH^`$``.GP^____R4`004(:``"``#IX/O_
M__\E!$$%"&@(`@``Z=#[____)0A!!0AH$`(``.G`^____R4,004(:!@"``#I
ML/O___\E$$$%"&@@`@``Z:#[____)11!!0AH*`(``.F0^____R48004(:#`"
M``#I@/O___\E'$$%"&@X`@``Z7#[____)2!!!0AH0`(``.E@^____R4D004(
M:$@"``#I4/O___\E*$$%"&A0`@``Z4#[____)2Q!!0AH6`(``.DP^____R4P
M004(:&`"``#I(/O___\E-$$%"&AH`@``Z1#[____)3A!!0AH<`(``.D`^___
M_R4\004(:'@"``#I\/K__P```````````````#'M7HGA@^3P4%12:&#-!`AH
M<,T$"%%6:)"Y!`CH(_S___20D)"0D)"0D)"0D)"0D%6)Y5.#[`2`/7A!!0@`
M=3^A?$$%"+OP/@4(@>OL/@4(P?L"@^L!.=AS'HVV`````(/``:-\004(_Q2%
M[#X%"*%\004(.=ARZ,8%>$$%"`&#Q`1;7<.-="8`C;PG`````%6)Y8/L&*'T
M/@4(A<!T$K@`````A<!T"<<$)/0^!0C_T,G#D)"0D)"0D)"0D)"0D%6)Y5:+
M=0A3#[8.B?"$R70IH3C0!`B-5@$/MAB)\.L*#[8*@\(!A,ET$#C9=?(/M@J)
MT(/"`83)=?!;7EW#9I!5,=*)Y5>)QU:#QQQ3@>Q0`0``C;6T_O__B86L_O__
MD(L,EXG(B<O!XQC!Z!@)V(G+P>,(@>,``/\`P>D("=B!X0#_```)R(D$EH/"
M`8/Z$'7.C97H_O__C4WHD(UT)@"+0NPS`C-"U#-"S,'('XE"#(/"!#G*=>B+
MA:S^__^+E:S^__^+`(G1B86H_O__BT$0BXVH_O__BW($BWH(`X6T_O__BU(,
MP<D;C8P(F7F"6HGPB?OWT"'S(=`)V(N=J/[__P'!BX6H_O__P<X"`Y6X_O__
M(?/WT"'X"=B+G:C^__^-E`*9>8):B<C!R!L!P@.]O/[__XG0P<@;P<L"C80'
MF7F"6HG/B86D_O__B<@AW_?0(?`#M<#^__\)^`.%I/[__XG7P<D"B;6D_O__
MB=8AS_?6(=X)_HN]I/[__P.=Q/[__\'*`HVT-YEY@EJ)M;#^__^)QL'.&P.U
ML/[__XGWP<\;C;P[F7F"6HG#B;VD_O__]].)QR'7(<L)^XGW`YVD_O__`XW(
M_O__P<@"(<>)C:3^__^)\??1(=$)^8N]I/[__P.5S/[__\'.`HV,#YEY@EJ)
MC;#^__^)V<')&P.-L/[__XG/P<\;C;PZF7F"6HG:]](AP@.%T/[__XF]I/[_
M_XG?(?<)^HG/`Y6D_O__B86D_O__B<C!RP+WT"'?(?`)^(N]I/[__P.UU/[_
M_\')`HV$!YEY@EJ)A;#^__^+O;#^__^)T,'(&P''B?C!R!N-A`:9>8):B=:)
MA:3^__^)T"'.]]`AV`.=V/[__PGP`X6D_O__B?[!R@*)G:3^__^)^R'6]],A
MRPGSB[6D_O__`XW<_O__P<\"C9P>F7F"6HF=L/[__XG#P<L;`YVP_O__B=[!
MSAN-M#&9>8):B<'WT2'1`Y7@_O__B;6D_O__B<8A_@GQB=X#C:3^__^)E:3^
M__^)VL'(`O?2(<8A^@GRB[6D_O__`[WD_O__P<L"C906F7F"6HF5L/[__XNU
ML/[__XG*P<H;`=:)\L'*&XV4%YEY@EJ)SXF5I/[__XG*(=_WTB'"`X7H_O__
M"?H#E:3^__^)]\')`HF%I/[__XGP(<_WT"'8"?B+O:3^__\#G>S^___!S@*-
MA`>9>8):B86P_O__B[VP_O__B=#!R!L!QXGXP<@;C80#F7F"6HG3B86D_O__
MB=`A\_?0(<@#C?#^__\)V`.%I/[__XG[P<H"B8VD_O__B?DAT_?1(?$)V8N=
MI/[__\'/`HV,"YEY@EJ)C;#^__^+G;#^__^)P<')&P.U]/[__P'+B=G!R1N-
MC`Z9>8):B<:)C:3^__^)P2'^]]$AT0.5^/[__PGQ`XVD_O__B=[!R`*)E:3^
M__^)VB'&]](A^@GRB[6D_O__`[W\_O__P<L"C906F7F"6HF5L/[__XNUL/[_
M_XG*P<H;`=:)\L'*&XV4%YEY@EJ)SXF5I/[__XG*(=_WTB'""?J)]P.5I/[_
M_\')`@.%`/___R'/B86D_O__B?#WT"'8"?B+O:3^___!S@(#G03___^-A`>9
M>8):B?>)A;#^__^)T#'/P<@;,=<#A;#^__^-O#NAZ]ENP<H"B</!RQL#C0C_
M__^-'!^)US'W,<>-O#FAZ]ENB=G!R`+!R1L#M0S___^-#`^)QS'7,=^-O#ZA
MZ]ENB<[!RP+!SAL#E1#___^--#>)WS'',<^-O#JAZ]ENB?+!R0+!RAL#A13_
M__^-%!>)SS'?,?>-O#BAZ]ENB=#!R!L!Q\'.`HGP`YT8____,<@QT,'*`HV<
M`Z'KV6Z)^,'(&P.-'/___XT$`XG3,?,Q^XV<&:'KV6Z)P<'/`L')&P'+B?D#
MM2#___\QT3'!P<@"C;0.H>O9;HG9P<D;`Y4D____C0P.B<8Q_C'>C;0RH>O9
M;HG*P<L"P<H;`=:)V@.]*/___S'",<K!R0*-O!>AZ]ENB?+!RAL#A2S___^-
M%!>)SS'?,?>-O#BAZ]ENB=#!R!L!Q\'.`HGP`YTP____,<@QT,'*`HV<`Z'K
MV6Z)^,'(&P.--/___XT$`XG3,?,Q^XV<&:'KV6Z)P<'/`L')&P'+B?D#M3C_
M__\QT3'!P<@"C;0.H>O9;HG9P<D;`Y4\____C0P.B<8Q_C'>C;0RH>O9;HG*
MP<L"P<H;`=:)V@.]0/___S'",<K!R0*-O!>AZ]ENB?+!RAL#A43___^-%!>)
MSS'?,?>-O#BAZ]ENB=#!R!L!Q\'.`HGP`YU(____,<@QT,'*`HV<`Z'KV6Z)
M^,'(&P.-3/___XT$`XG3,?,Q^XV<&:'KV6Z)P<'/`L')&XT,"XG[`[50____
M,=,QPP.55/___XVT'J'KV6Z)R\'(`L'+&XT<'HG&B96D_O__"?Z)PB'Z(<X)
MUHN5I/[__P.]6/___\')`HVT,MR\&X^)VL'*&XT4%HG.B;VD_O__"<:)SR''
M(=X)_HN]I/[__P.%7/___\'+`HVT-]R\&X^)WXF%I/[__PG/B=B)M;#^__^)
MUL'.&P.UL/[__R'7(<@)QXN%I/[__P.-8/___\'*`HV\.-R\&X^)\,'(&XT$
M!XG7B8VD_O__"=^)T2'9(?<)SXN-I/[__P.=9/___\'.`HV\.=R\&X^)P<')
M&XT,#XGWB9VD_O__"=>)\R'3(<<)WXN=I/[__P.5:/___\'(`HV\.]R\&X^)
MR\'+&XT<'XG'B96D_O__"?>)PB'R(<\)UXN5I/[__P.U;/___\')`HV\.MR\
M&X^)VL'*&XT4%XG/B;6D_O__"<>)SB'?(<8)]XNUI/[__\'+`HV\/MR\&X^)
MUL'.&P.%</___XTT-XG?"<^)A:3^__^)V"'7(<@)QXN%I/[__P.-=/___\'*
M`HV\.-R\&X^)\,'(&XT$!XG7B8VD_O__"=^)T2'9(?<)SXN-I/[__P.=>/__
M_\'.`HV\.=R\&X^)P<')&XT,#XGWB9VD_O__"=>)\R'3(<<)WXN=I/[__P.5
M?/___\'(`HV\.]R\&X^)R\'+&XT<'XG'B96D_O__"?>)PB'R(<\)UXN5I/[_
M_P-U@,')`HV\.MR\&X^)VL'*&XT4%XG/B;6D_O__"<>)SB'&(=\)]XNUI/[_
M_XV\/MR\&X^)UL'.&P-%A,'+`HTT-XG?B86D_O__"<^)V"'((=<)QXN%I/[_
M_P--B,'*`HV\.-R\&X^)\,'(&XT$!XG7B8VD_O__"=^)T2'9(?<)SXN-I/[_
M_P-=C,'.`HV\.=R\&X^)P<')&XT,#XGWB9VD_O__"=>)\R'3(<<)WXN=I/[_
M_P-5D,'(`HV\.]R\&X^)R\'+&XT<'XG'B96D_O__"?>)PB'R(<\)UXN5I/[_
M_P-UE,')`HV\.MR\&X^)VL'*&XT4%XG/B;6D_O__"<>)SB'?(<8)]XNUI/[_
M_P-%F,'+`HV\/MR\&X^)UL'.&XTT-XG?B86D_O__"<^)V"'((=<)QXN%I/[_
M_P--G,'*`HV\.-R\&X^)\,'(&XT$!XG7B8VD_O__"=^)T2'9(?<)SXN-I/[_
M_P-=H,'.`HV\.=R\&X^)P<')&P'/B?&)G:3^__\)T8GS(=,AP0G9BYVD_O__
MP<@"`U6DC8P+W+P;CXG#B8VP_O__B?DQ\\')&S'[`XVP_O__C9P:UL%BRL'/
M`HG*P<H;`=.)^@-UJ#'",<K!R0*-M!;6P6+*B=K!RAL#1:R-%!:)SC'^,=Z-
MM##6P6+*B=#!RP+!R!L!QHG8`WVP,<@QT,'*`HV\!];!8LJ)\,'(&P--M(T$
M!XG7,=\Q]XV\.=;!8LJ)P<')&\'.`@'/`UVXB?$QT3'!C9P+UL%BRHGYP<@"
MP<D;`U6\C0P+B<,Q\S'[C9P:UL%BRHG*P<\"P<H;`=.)^@-UP#'",<K!R0*-
MM!;6P6+*B=K!RAL#1<2-%!:)SC'^,=Z-M##6P6+*B=#!RP+!R!L!QHG8`WW(
M,<@QT,'*`HV\!];!8LJ)\,'(&P--S(T$!XG7,=\Q]XV\.=;!8LJ)P<')&\'.
M`@'/`UW0B?$QT3'!C9P+UL%BRHGYP<@"P<D;`U74C0P+B<,Q\S'[C9P:UL%B
MRHG*P<\"P<H;`=.)^@-UV#'",<K!R0*-M!;6P6+*B=K!RAL#1=R-%!:)SC'^
M,=Z-M##6P6+*B=#!RP+!R!L!QHG8`WW@,<@QT,'*`HV\!];!8LJ)\,'(&P--
MY(T$!XG7,=\Q]XV\.=;!8LJ)P<'.`L')&P-=Z(T,#XGW,=<QQXV\.];!8LJ)
MR\'(`L'+&P-5[(T<'XG',?<QSXV\.M;!8LJ)VL'*&P'7BY6H_O__`U7PP<D"
MC;06UL%BRHG*,<(QVHT4%HG^P<X;`?*+M:S^___!RP*)%@%^!`%>"`%.#`%&
M$('$4`$``%M>7UW#C;8`````C;PG`````%6)Y8/L.(7`B5WTB<.)=?B)??R)
M5=QU$#'`BUWTBW7XBWW\B>Q=PY"A8$$%"(7`B47@=.0/M@,\/71=A,")VG17
M@\(!#[8"/#UT!(3`=?(IVHM%X(LPA?9TOHE=Y(G'B=.-M"8`````BT7DB5PD
M"(DT)(E$)`3HR?#__X7`=0:`/!X]=!N#QP2+-X7V==IFD.N&C;8`````,=+K
MM8UT)@`K?>"+1=S!_P*).(U$'@'I9O___XVV`````(V_`````%6)Y8/L&(U5
M].@R____R<-5B>6#[`BA2$$%"(/X_W0(R<.-M@````"X*,X$".C.____A<!T
M&@^V`(3`=!,\,`^5P`^VP*-(004(R<.-="8`,<#K\8VV`````(V_`````%6)
MY5:)QE.#[!"-7?3K&9"+1?3!X`(#!6!!!0B#P`2+$(72B5#\=?2)VHGPZ*_^
M__^%P'7;@\006UY=PXUT)@!5B>6![$@0``")??R-O>3O__^)7?2)TXEU^&6A
M%````(E%Y#'`B8W4[___QT0D"/\/``")?"0$QP0D,LX$".@A[___A<")QGYW
MC4#_@+P%Y.___P!T8HET)`C'1"0$+P```(D\).AJ[___A<!T4L<$)`````#H
MNN___XL`B00DZ*#L__^)="0,B7PD"(E<)`2)!"3H[.W__XM%Y&4S!10```!U
M2HM=](MU^(M]_(GL7<.-M"8`````A<!T!(G&ZY;'!"0`````Z&CO__^+`(D$
M).A.[/__BY74[___B5PD!(E4)`B)!"3H".S__^NJZ"'N__^-M@````"-O"<`
M````58GE@^P8QP0D`````.@B[___BP")!"3H".S__\=$)`3_____B00DZ$CL
M___'!"0`````Z/SN__^+`(D$).CBZ___QT0D"`````#'1"0$D*T$"(D$).@Z
M[___R<.-="8`58GE4X/L%,<$)`````#HP>[__XL`B00DZ*?K__^)!"3H/^K_
M_XL`BU@$QP0D`````.B>[O__BP")!"3HA.O__XD$).C,ZO__#[8`B$,8QP0D
M`````.AZ[O__BP")!"3H8.O__XD$).CXZ?__BP"+6`3'!"0`````Z%?N__^+
M`(D$).@]Z___B00DZ)7J__^+``^W0!!F)?\!9HE#&L<$)`````#H*^[__XL`
MB00DZ!'K__^)!"3HJ>G__XL`BU@$QP0D`````.@([O__BP")!"3H[NK__\=$
M)`@`````QT0D!,S/!`B)!"3H9NW__XE#',<$)`````#HU^W__XL`B00DZ+WJ
M__^)!"3H5>G__XL`BU@$QP0D`````.BT[?__BP")!"3HFNK__XD$).C"Z?__
MBP")0R#'!"0`````Z)'M__^+`(D$).AWZO__B00DZ`_I__^+`(M8!,<$)```
M``#H;NW__XL`B00DZ%3J__^)!"3H;.S__S'2BP"%P'0CQP0D`````.A([?__
MBP")!"3H+NK__XD$).A&[/__BP"+4&R)4R3'!"0`````Z"+M__^+`(D$).@(
MZO__B00DZ*#H__^+`(M`!,=`*`````#'!"0`````Z/CL__^+`(D$).C>Z?__
MB00DZ';H__^+`(M`!,=`+`````#'!"0`````Z,[L__^+`(D$).BTZ?__B00D
MZ$SH__^+`(M8!,<$)`````#HJ^S__XL`B00DZ)'I__^)!"3H:>S__XL`B4,P
M@\046UW#C78`C;PG`````%6)Y5>)QU93@>R<````A<!T!8`X`'41@<2<````
M6UY?7<.-M@````")!"3HU.G__X7`B<9TX6:0B30DZ#3J__^%P`^$T````(U8
M$P^V%4+.!`@/MD`3.=`/A-H````/MA5!S@0(.=`/A.,```")/"3H+^K__XD<
M)(E%@.@DZO__BU6`C40"`HD$).BUZO__B46$B5PD%(E\)!#'1"0,1,X$",=$
M)`C_____QT0D!`$```")!"3H6NO__XU%B(E$)`B+183'!"0#````B40D!.C@
MY___@_C_=!.+19@E`/```#T`0```#X2,````BT6$B00DZ+WI__^+182)!"3H
MLNC__XDT).AJZ?__A<`/A3;___^-M@````")-"3HY.G__XD\).A,ZO__@<2<
M````6UY?7<.0C70F``^V4P$Z%4/.!`@/A/#^___I$?___XUV``^V0P$Z!4+.
M!`@/A0W___\/MD,".@5#S@0(#X3(_O__Z?C^__^-=@"+183H@/[__^ER____
MC70F`(V\)P````!5B>53B<.#[!3'!"0`````Z-_J__^+`(D$).C%Y___B00D
MZ.WI__^)7"0$QP0D`P```(E$)`CH">C__X7`=`F#Q!0QP%M=PY#'!"0`````
MZ*#J__^+`(D$).B&Y___B00DZ*[I__^+0!`E`/```#T`0```="W'!"0`````
MZ'/J__^+`(D$).A9Y___B00DZ('I__^+0!`E`/```#T`H```=9V)'"3'1"0$
M`@```.BBY___A<`/E,"#Q!0/ML!;7<-5B>6![$@@``")7?2-G>/O__]EH10`
M``")1>0QP(EU^(E]_.BLY?__QT0D%#W.!`C'1"0,2LX$",=$)`@!$```QT0D
M!`$```")'"2)1"00Z'#I__^%P'D@,=N+5>1E,Q44````B=AU5XM=](MU^(M]
M_(GL7<.-=@"-O>+?___'1"0(`!```(E\)`2)'"3HTNC__X7`B<9XP(U``8D$
M).A1Z/__A<")PW2QB70D"(E\)`2)!"3H>^?__\8$,P#KF^A0Z/__C;8`````
MC;\`````58GE@^P(R>DD____C70F`%6)Y5=6B<93,<"#[#R)TX`Z/0^4P`'#
MB1PDZ%7G__^-5>2)QXGPZ)7W__^%P'0QB00DB470Z#KG__\QR8M5T#G'#X=Y
M`0``D`^V!`N(!`J#P0&$P'7R@\0\,<!;7E]=PZ%@004(,=*Y"````(,X`'08
MC;0F`````(/"`8L,D(7)=?:-#)4(````@SV`004(`'0NB4PD!(D$)(E5T.C#
MY/__A<")P:-@004(BU70#X4;`0``@\0\N/____];7E]=PXD,),<%@$$%"`$`
M``")5=#H/^?__XM5T(7`B<%TU8T$E0````")1=2)1"0(H6!!!0B)#"2)1"0$
MB4W,Z)3G__^+3<R)#6!!!0B+5=#'1)$$`````(E5Y`^V%H#Z/0^$F0```(32
MB?`/A(\```"-=@"#P`$/MA"`^CUT!(32=?$I\(M5U(U$.`(#%6!!!0B)!"2)
M5=#HN^;__XM5T(7`B0(/A$W___^+5>2A8$$%"(L$D`^V%H32B!!T)X#Z/70B
M@\8!ZPZ-="8`@/H]D(UT)@!T#P^V%H/``8/&`832B!!UY\8`/3'29I`/M@P3
MB$P0`8/"`83)=?'IFO[__S'`ZX&+1>3!X`*)1=3I2?___XT$E0````")1=3I
M+____XUV`%6)Y5>_8,X$"%93NU;.!`B#[&R-==C'1=!@S@0(QT745LX$",=%
MV&/.!`C'1=Q9S@0(QT7@7LX$",=%Y,S/!`CK*HVV`````(M%"(D4)(E5O(E$
M)`3HRN7__X7`=#J`.P!T*HL&B=^#Q@2)PXGXZ"WV__^%P(G"=`6`.`!URHM5
M"(GXZ)C]__^`.P!UUH/$;%M>7UW#C78`BTT(B0PDZ/'D__^)1<2A/-`$"(D$
M).CAY/__BU6\B10DB47`Z-/D__^+3<")1;2+1<2-3`@"BT6T`<B)!"3H6>7_
M_XM5O,=$)`Q[SP0(QT0D"/_____'1"0$`0```(E4)!B)P:$\T`0(B0PDB4V\
MB40D%(M%"(E$)!#H[>7__XM-O(GXB<KH_?S__^DV____D(VT)@````!5B>57
M5H/L,&6A%````(E%]#'`H130!`B)1=*A&-`$"(E%UJ$<T`0(B47:H2#0!`B)
M1=ZA)-`$"(E%XJ$HT`0(B47FH2S0!`B)1>JA,-`$"(E%[@^W!330!`AFB47R
MN'#.!`CH:/7__[AYS@0(Z%[U__^X@<X$".A4]?__N(K.!`CH2O7__[B1S@0(
MZ$#U__^XH<X$".@V]?__N*W.!`CH+/7__[@HS@0(Z"+U__^XMLX$".@8]?__
MN,#.!`CH#O7__[C*S@0(Z`3U__^XU\X$".CZ]/__N.#.!`CH\/3__[CKS@0(
MZ(;T__^%P'0,B<*XMLX$".CV^___N/S.!`CH;/3__X7`=`R)PK@.SP0(Z-S[
M__^X&<\$".A2]/__A<!T+HG"N*W.!`CHPOO__[I%SP0(N)'.!`CHL_O__XM%
M]&4S!10```!U1X/$,%Y?7<.X*<\$".@6]/__A<!T$HG"N"C.!`CHAOO__^O"
MC70F`(UUX[\ZSP0(N0H```#SIG6MC57MN"C.!`CH8OO__^N>Z(_C__^-="8`
MC;PG`````%6)Y8/L&.CYXO__B00DZ-'B__^)PC'`A=)T`HL"R<.058GE5E.#
M[!"+70B%VW1A@#L`=%R)'"3HB.+__XU$`_\YPP^#Z````(LU.-`$"`^V"`^V
M%CC1=`SK6HVV`````#@(=5"#Z`$YPW+U.=B-=@!U5@^V`#H&#X23````B74(
M@\006UY=Z5GD__^0C70F`,<$)`(```#HR.+__X7`=`5FQP`N`(/$$%M>7<.-
M="8`.!!TMX/H`3G#<O4YV(UV`'2PC;8`````@^@!.<-S!P^V$#H6=/*)PC'`
M*=J-2@*!^0`0``!WOH/"`<=$)`P`$```B50D"(E<)`3'!"2@004(Z&[?__^X
MH$$%".N8C78`QP0D`@```.A(XO__B<(QP(72=(%FQP(N`(G0Z77___^+-3C0
M!`CI,/___Y"-="8`58GE5U93@^P<BW4(B30DZ,S^__\/M@B)QXG#A,ET*Z$X
MT`0(C5<!#[8`ZPZ-="8`#[8*@\(!A,ET$#C!=?(/M@J)TX/"`83)=?#H4?+_
M_X7`=!V%]G09@#X`=!3'1"0$1\\$"(D<).BHX?__.=AT"(/$'%M>7UW#@\0<
MB?!;7E]=Z5KV__^-=@"-O"<`````58GE@^3P5E.#[#B-11")1"0(C44,B40D
M!(U%"(D$).B@XO__QT0D"%28!`C'1"0$5)@$",<$)"2:!`CH4!,``,<$)```
M``#HJ-___X`X`'4[Z([?__^%P*.@404(#X2Q`0``B00DZ$G@___'!"0`````
MZ%WB__^+`(D$).A#W___B00DZ*OA___&``#'!"0`````,=OH.N+__XL`B00D
MZ"#?__^)!"3H..+__X`(`L<$)`````#H&>+__XL`B00DZ/_>__^)!"3H%^+_
M_X`(`8M5"(E<)"R#P@6)5"0HWVPD*-@%P-`$"-T%R-`$"-G)VNG?X)X/AP4!
M``#!X@*)%"3H/N'__XMU#*.L404(BQ;'0`1,SP0(QT`(X-`$",=`#$_/!`B)
M$(M=",<%J%$%"`0```"#^P%^%;H!````9I"+#):)3)`,@\(!.=-_\H/#`\<$
MF`````")1"0,H:!1!0B)7"0(QT0D$`````#'1"0$L,P$"(D$).@WW?__A<")
MPW0]H:!1!0B)!"3HY-___[BAS@0(Z&;P__^%P'0ZH:!1!0B)!"3HZ=S__^BT
MWO__@\0XB=A;7HGL7<.0C70F`*&@404(B00DZ(?=__^)P^NRC;0F`````*&D
M404(A<!T"HD$).B'_?__Z[.XK<X$".@+\/__A<"CI%$%"'2@Z^''1"0$9$$%
M",<$)%/.!`CH$.#__\<$)`$```#H!.'__U6)Y5=64X'L3!```(M%"&6+%10`
M``")5>0QTHMU#(F%U.___[BMS@0(Z++O__^+'3C0!`B)7"0$B<>+A=3O__^)
M!"3H'-___X7`=#&+E=3O__^XRLX$".@$]___BU7D93,5%````(N%U.___P^%
MJ0$``('$3!```%M>7UW#BY74[___B10DZ$G>__^)-"2)A=#O__^A/-`$"(E$
M)`3H$M___X7`B<9TI(N5T.___X/"`8F5T.___Y"`/@!U!;Y"S@0(A?]T%(ET
M)`2)/"3H`N#__X7`#X3:````B30DZ/+=__\/ME0&_SH3=1>-%`9FD`^V2OZ#
MZ`'&0O\`@^H!.@MT[@.%T.___SW_#P``#X\Y____BY74[___C87D[___B5PD
M%(ET)!#'1"0,>\\$"(E4)!C'1"0(`!```,=$)`0!````B00DZ/G>___'!"0`
M````Z%W?__^+`(D$).A#W/__B00DZ&O>__^-E>3O__^)5"0$QP0D`P```(E$
M)`CH8=O__X7`=2W'!"0`````Z"'?__^+`(D$).@'W/__B00DZ"_>__^+0!`E
M`/```#T`@```="2A/-`$",<$)`````")1"0$Z.O=__^%P(G&#X7E_O__Z73^
M__^-A>3O___'1"0$`0```(D$).@FW/__A<!UPHV5Y.___[C*S@0(Z%[U__^-
ME>3O__^)%"3HY-[__XF%U.___^E!_O__Z'3=__]5B>575E.![$R!``"+10AE
MBQ44````B57D,=+'A2A___]2SP0(QX4L?___6L\$"(F%!'___[BMS@0(QX4P
M?___0LX$",>%-'___\S/!`C'A1!___\.SP0(QX44?___!\\$",>%&'___U_/
M!`C'A1Q___]5SP0(QX4@?___9\\$",>%)'___\S/!`C'A3A___]KSP0(QX4\
M?___<,\$",>%0'___\S/!`CH$^W__X7`=`F`.``/A78#``"-M@````#H*_G_
M_X7`B<</A(D#```/MA^$VW0BZ%G;__^)^HUV`(L(#[[;]@19"'4#Q@)?@\(!
M#[8:A-MUZ(V=%'___[@.SP0(ZQ&-=@"+`X/#!(`X``^$B@(``.BE[/__A<")
MQG3GZ'KR__^%P'3>B30DZ*+=__^%P'32B<:)-"3H=-O__XD\)(G#Z&K;__^-
ME`,$!```B10DB97T?O__Z/7;__^+E?1^__^)%"2)PXF%_'[__^C?V___BPTX
MT`0(B7PD',=$)!A'SP0(B70D$(E,)!3'1"0,><\$"(F%`'___\=$)`C_____
MQT0D!`$```")!"3H;]S__XN]`'___\=$)`3M`0``B3PDZ'G8__^X6<X$".CK
MZ___A<`/A+L"``")!"3H[]S__XN5!'___XE$)`2+`HD$).CG^___A<")P@^$
ME0(``(D4)(F5]'[__^BCVO__BY7T?O__@_@#B87X?O__?CZ-=`+\OX+/!`BY
M!0```/.F=2R#O?A^__\$#X2?`0``B[WX?O__BPTXT`0(#[9$.OLZ`0^$A@$`
M`(VV`````(F5!'___^AEZ___A<!U)(N%!'___\=$)`0`````B00DZ,_;__^%
MP(F%!'___P^%%0(``+I%SP0(N"C.!`CHGO+__S'VZ(O7__^+E0!____'1"0<
MS,\$",=$)`R@SP0(QT0D"/____^)5"00QT0D!`$```")1"08H3C0!`B)'"2)
M1"04Z#S;__^+O0!____K5N@?U___@S@1=6&-M@````#H+]?__XL-.-`$"(/&
M`<=$)"#,SP0(B70D'(E\)!")3"04QT0D#*[/!`B)1"08QT0D"/_____'1"0$
M`0```(D<).C>VO__QT0D!.T!``")'"3H[M;__X/X_W25B[T`?___B3PDZ%O8
M__^)VKBMS@0(Z,OQ__^)'"3HH_/__XM5Y&4S%10```"+A?Q^__\/A5T&``"!
MQ$R!``!;7E]=PV:0C;4L?___NU+/!`CK#8UV`(L>@\8$@#L`=!N)V.C?[___
M,=*%P'3IB1PDZ`7;__^%P(G"=-N)UNE<_?__C70F`(N]!'___XM_!(7_B;T$
M?___#X1I_O__B3PDB97T?O__Z*_8__^+E?1^__^#^`,/ADS^__^-=`?\N04`
M``"_A\\$"/.F#X0\_O__Z3'^__^0B00DB87T?O__Z.+R__^+A?1^__^)!"3H
MB-K__XF%_'[__^DF____D(V=/'___[AKSP0(D(UT)@#H4^G__X7`=!")!"3H
M6]K__X7`#X7A!```BP.#PP2`.`!UW;^_SP0(Z6/\__^-=@"+C01___^+$>E>
M_?__C78`QT0D#`(```#'1"0$[O___\=$)`C_____B00DZ#S6__^+C01___^-
ME41____'1"0(!@```(E4)`2)#"3HK-;__X"]1'___P!U#8"]17___T,/A&L$
M``"+A01____'1"0,`````,=$)`0`````QT0D"`````")!"3HX-7__XV58/__
M_\>%1/___P$C16?'A4C___^)J\WOQX5,_____MRZF,>%4/___W94,A#'A53_
M___PX=+#QX58____`````,>%7/___P````#'1:``````B97D?O__B9WX?O__
MD(UT)@"+E01___^-A41____'1"0(`(```(E$)`2)%"3H[-7__X7`B<,/CGX!
M``"+C5C___^-O41___^+A5S___^-%-DYRH/0`(F%7/___XG8P>@=`85<____
MBT6@B958____A<!T5KI`````B=\IPCG3?@*)UXV-8/___XT$`8V51'___XE\
M)`B)5"0$B00DZ'S6__^+1:`!^(/X0(E%H`^%7____XV-1'___RG[C85$____
MC3PYZ.'9__^0@_L_#XZ\````,?:0C70F`(L$-XF%8/___XM$-P2)A63___^+
M1#<(B85H____BT0W#(F%;/___XM$-Q")A7#___^+1#<4B85T____BT0W&(F%
M>/___XM$-QR)A7S___^+1#<@B46`BT0W)(E%A(M$-RB)18B+1#<LB46,BT0W
M,(E%D(M$-S2)192+1#<XB468BT0W/(/&0(E%G(V%1/___^@[V?__B=@I\(/X
M/P^/7O___X/K0(G8P>@&B<+!X@:-?#I`*=.)?"0$C;U@____QT0D#$0```")
M7"0(B3PDZ%'4__^)7:#I7?[__Y"-="8`BXT$?___BYWX?O__B0PDZ.#5__^+
MM5C___^+E5S___^)\,'H`X/@/\:$!6#___^`@\`!@_@X#X^G`0``N3@```"-
MO6#___\IP8T$!XF5]'[__XE,)`C'1"0$`````(D$).BNT___BY7T?O__B=#!
MZ!B(19B)T,'H$(A%F8G0P>@(B$6:B?#!Z!B(19R)\,'H$(A%G8GPP>@(B$6>
MB?`Q]HA%GXV%1/___XA5FXU]I^@\V/__BY5$____B='!Z1B)R(A-T(G1P>D0
MB$W1B=&(5=.+E4C____!Z0B(3=*)T<'I&(A-U(G1P>D0B$W5B=&(5=>+E4S_
M___!Z0B(3=:)T<'I&(A-V(G1P>D0B$W9B=&(5=N+E5#____!Z0B(3=J)T<'I
M&(A-W(G1P>D0B$W=B=&(5=^+E53____!Z0B(3=Z)T<'I&(A-X(G1P>D0B$WA
MB='!Z0B(3>*(5>/K"(UV``^V1#70#[;`@\8!B3PD@\<"B40D$,=$)`R;SP0(
MQT0D"/_____'1"0$`0```.ABU?__@_X4=<G&1<\`C56GQT0D',S/!`B+#3C0
M!`B+O0!___^)5"08QT0D#(S/!`B)3"04B7PD$,=$)`C_____QT0D!`$```")
M'"3H%M7__^E(^O__C;U@____N4`````IP8T$!XE,)`B)E?1^___'1"0$````
M`(D$).@'TO__C85$____Z-C6__^+O>1^__^Y#@```#'`\ZN+E?1^___I.O[_
M_XG'Z6;W__^`O49___]!#X6(^___@+U'?___0P^%>_O__X"]2'___T@/A6[[
M__^`O4E___]%#X5A^___B[T$?___QT0D#`(```#'1"0$QO___\=$)`C_____
MB3PDZ$'1__^-A41____'1"0(*0```(E$)`2)/"3HM]'__XV51'___\=$)!S,
MSP0(Z>;^___H?]/__XUT)@"-O"<`````58GE5U93@^PLQP0D`````.A_U/__
MBP")!"3H9='__XD$).C=T?__Q@`!N)'.!`CHC./__X7`=`F`.#$/A!<#``"-
MM"8`````Z`/N___'!"0`````Z#O4__^+`(D$).@AT?__QT0D#`L```#'1"0(
M`0```,=$)`3&SP0(B00DZ+'0__^%P`^$W0```(M`##'VNP$```"+0!B)1>2A
MJ%$%"(/X`7\ZZ;,```"-M@````"+1PR+%:Q1!0B+%)J)1"0$B10DZ.S3__^%
MP`^%B````*&H404(@\,!@\8!.=A^?L<$)`````#HJ=/__XL`B00DZ(_0__^+
M5>3'1"0,`````(ET)`B)5"0$B00DZ/31__^%P'1$BSCV1PD$=93'!"0`````
MZ&S3__^+`(D$).A2T/__QT0D#`(```#'1"0(`````(E\)`2)!"3HMM/__^E@
M____D(UT)@"AJ%$%"(U0_SGR#X2``0``QP0D`````.@@T___BP")!"3H!M#_
M_\=$)`P%````QT0D"`$```#'1"0$R\\$"(D$).B6S___A<")PW0^BT`,BS#'
M!"0`````Z-_2__^+`(D$).C%S___QT0D",W/!`B)="0$B00DZ('/__^+0PR+
M&/9#"D`/A4X!``#'!"0`````Z*;2__^+`(D$).B,S___QT0D#`4```#'1"0(
M`0```,=$)`3IS@0(B00DZ!S/__^%P(G#=#^XRLX$".B8X?__A<")Q@^$/@$`
M`(M##(LXQP0D`````.A1TO__BP")!"3H-\___XET)`B)?"0$B00DZ/?.___'
M!"0`````Z"O2__^+`(D$).@1S___B00DZ(G/___&``#'!"0`````Z`K2__^+
M`(D$).CPSO__B00DZ"C2___'``````"XK<X$".@4X?__A<"CI%$%"`^$YP``
M`,=$)`3M`0``B00DZ'O-__^#^!%T#87`=`F#^/\/A2H!``"#Q"Q;7E]=PY"-
M="8`@_@!#XYW_O__NP$```!FD,<$)`````"#PP'HC='__XL`B00DZ'/.__^+
M5>2)5"0$B00DZ`3.__\Y':A1!0A_T.D[_O__C78`QP0D`````.A8T?__BP")
M!"3H/L[__XE<)`2)!"3H$M#__^F+_O__D(!X`0`/A.O\__^-M@````#IU/S_
M_XUV`*&L404(BSB+0PR+,,<$)`````#H#-'__XL`B00DZ/+-__^)^8GRZ,7@
M___IO?[__Z&L404(B00DZ%/R__^+/:Q1!0BCI%$%"(M##(LP]D8)!`^$E@``
M`(M&#(E\)`2)!"3HSL[__XG&BT,,BQCV0PD$=$:+0PR)1"0(H:Q1!0B)="0,
MBP#'!"1`T`0(B40D!.C?S___B40D#*&D404(B40D"*&L404(BP#'!"1PT`0(
MB40D!.B[S___QP0D`````.A?T/__BP")!"3H1<W__\=$)`P"````QT0D"```
M``")7"0$B00DZ*G0___KB<<$)`````#H*]#__XL`B00DZ!'-___'1"0,`@``
M`,=$)`@`````B70D!(D$).AUT/__Z3;___^-M@````"-OP````!5B>6#[!C'
M!"0`````Z.+/__^+`(D$).C(S/__QT0D#-+/!`C'1"0(%)H$",=$)`3<SP0(
MB00DZ)C/___)PV:058GE@^PHQP0D`````.BBS___BP")!"3HB,S__XD$).B<
M____QP0D`````.B$S___BP")!"3H:LS__\=$)!0`````QT0D$,S/!`C'1"0,
MS,\$",=$)`C0QP0(QT0D!/C/!`B)!"3H&LW__\G#D)"0D%6)Y5/H,@```('#
MRW(``(/L$(N#4`$``(E$)`R+11")1"0(BT4,B40D!(M%"(D$).AOR___@\00
M6UW#BQPDPY!5B>5=PXUT)@"-O"<`````58GE5U93Z.#___^!PWER``"#[!SH
M&\K__XV[\/[__XV#\/[__RG'P?\"A?]T)#'VBT40B40D"(M%#(E$)`2+10B)
M!"3_E+/P_O__@\8!.?YRWH/$'%M>7UW#D)"0D)"058GE4X/L!*'D/@4(@_C_
M=!.[Y#X%"&:0@^L$_]"+`X/X_W7T@\0$6UW#D)!5B>53@^P$Z`````!;@</L
M<0``Z`S/__]96\G#```````````#`````0`"`%!!4E]#3$5!3@`O<')O8R]S
M96QF+V5X90`N+@`E<R\E<P`O<')O8R\E:2\E<P!,24)0051(`$193$1?3$E"
M4D%265]0051(`%!%4DPU3$E"`%!%4DQ,24(`4$523#5/4%0`4$523$E/`%!!
M4E])3DE424%,25I%1`!005)?4U!!5TY%1`!005)?5$5-4`!005)?1$5"54<`
M4$%27T-!0TA%`%!!4E]04D]'3D%-10!005)?05)'0P!005)?05)'5E\P`%!!
M4E]'3$]"04Q?1$5"54<`4$%27T=,3T)!3%]435!$25(`4$%27U1-4$1)4@!0
M05)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@!005)?0TQ%04X]`#$`
M<&%R+0`M90`M+0!#.EQ414U0`"]T;7``5$5-4$1)4@!435``55-%4@!54T52
M3D%-10`E<R5S)7,E<P!P87)L`"YP87(`)7,E<V-A8VAE+25S)7,`)3`R>``E
M<R5S=&5M<"TE=25S`"5S)7-T96UP+25U+25U)7,`4UE35$5-`$%21U8`&`!P
M97)L`'!E<FQX<VDN8P!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`26YT
M97)N86QS.CI005(Z.D)/3U0`+P`Z`````%]?14Y67U!!4E]#3$5!3E]?("`@
M("`@("`@("`@("`@``````W0!`@/T`0()7,Z(&5X96-U=&EO;B!O9B`E<R!F
M86EL960@+2!A8F]R=&EN9R!W:71H("5I+@H`)7,Z(&-R96%T:6]N(&]F('!R
M:79A=&4@=&5M<&]R87)Y('-U8F1I<F5C=&]R>2`E<R!F86EL960@+2!A8F]R
M=&EN9R!W:71H("5I+@H`````````````````@/___\]!<&%R+G!L````````
M`````",A+W5S<B]B:6XO<&5R;`IE=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@
M("U3("0P("1[,2LB)$`B?2<*("`@(&EF(#`[(",@;F]T(')U;FYI;F<@=6YD
M97(@<V]M92!S:&5L;`H*<&%C:V%G92!?7W!A<E]P;#L*"B,@+2TM(%1H:7,@
M<V-R:7!T(&UU<W0@;F]T('5S92!A;GD@;6]D=6QE<R!A="!C;VUP:6QE('1I
M;64@+2TM"B,@=7-E('-T<FEC=#L*"B-L:6YE(#$U.`H*;7D@*"1P87)?=&5M
M<"P@)'!R;V=N86UE+"!`=&UP9FEL92D["D5.1"![(&EF("@D14Y6>U!!4E]#
M3$5!3GTI('L*("`@(')E<75I<F4@1FEL93HZ5&5M<#L*("`@(')E<75I<F4@
M1FEL93HZ0F%S96YA;64["B`@("!R97%U:7)E($9I;&4Z.E-P96,["B`@("!M
M>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP
M*3L*("`@(&]U=',H<7%[4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")]
M*3L*("`@($9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R
M;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PH@("`@<FUD:7(@)'!A<E]T
M96UP.PH@("`@(R!$;VXG="!R96UO=F4@=&]P9&ER(&)E8V%U<V4@=&AI<R!C
M875S97,@82!R86-E('=I=&@@;W1H97(@87!P<PH@("`@(R!T:&%T(&%R92!T
M<GEI;F<@=&\@<W1A<G0N"@H@("`@:68@*"UD("1P87)?=&5M<"`F)B`D7D\@
M;F4@)TU35VEN,S(G*2!["B`@("`@("`@(R!3;VUE=&AI;F<@=V5N="!W<F]N
M9R!U;FQI;FMI;F<@=&AE('1E;7!O<F%R>2!D:7)E8W1O<GDN("!4:&ES"B`@
M("`@("`@(R!T>7!I8V%L;'D@:&%P<&5N<R!O;B!P;&%T9F]R;7,@=&AA="!D
M:7-A;&QO=R!U;FQI;FMI;F<@<VAA<F5D"B`@("`@("`@(R!L:6)R87)I97,@
M86YD(&5X96-U=&%B;&5S('1H870@87)E(&EN('5S92X@56YL:6YK('=I=&@@
M82!B86-K9W)O=6YD"B`@("`@("`@(R!S:&5L;"!C;VUM86YD('-O('1H92!F
M:6QE<R!A<F4@;F\@;&]N9V5R(&EN('5S92!B>2!T:&ES('!R;V-E<W,N"B`@
M("`@("`@(R!$;VXG="!D;R!A;GET:&EN9R!O;B!7:6YD;W=S(&)E8V%U<V4@
M;W5R('!A<F5N="!P<F]C97-S('=I;&P*("`@("`@("`C('1A:V4@8V%R92!O
M9B!C;&5A;FEN9R!T:&EN9W,@=7`N"@H@("`@("`@(&UY("1T;7`@/2!N97<@
M1FEL93HZ5&5M<"@*("`@("`@("`@("`@5$5-4$Q!5$4@/3X@)W1M<%A86%A8
M)RP*("`@("`@("`@("`@1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE
M*"1T;W!D:7(I+`H@("`@("`@("`@("!3549&25@@/3X@)RYC;60G+`H@("`@
M("`@("`@("!53DQ)3DL@/3X@,"P*("`@("`@("`I.PH*("`@("`@("!P<FEN
M="`D=&UP("(C(2]B:6XO<V@*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@
M9&\*("`@<FT@+7)F("<D<&%R7W1E;7`G"B`@(&EF(%L@7"$@+60@)R1P87)?
M=&5M<"<@73L@=&AE;@H@("`@("`@8G)E86L*("`@9FD*("`@<VQE97`@,0H@
M("!X/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R(@+B`D=&UP+3YF:6QE;F%M
M92`N("(G"B(["B`@("`@("`@("`@(&-H;6]D(#`W,#`L)'1M<"T^9FEL96YA
M;64["B`@("`@("`@;7D@)&-M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^+V1E
M=B]N=6QL(#(^)C$@)B<["B`@("`@("`@8VQO<V4@)'1M<#L*("`@("`@("!S
M>7-T96TH)&-M9"D["B`@("`@("`@;W5T<RAQ<2A3<&%W;F5D(&)A8VMG<F]U
M;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("D*("`@("`@("`@("`@
M("X@)'1M<"T^9FEL96YA;64I.PH@("`@?0I]('T*"D)%1TE.('L*("`@($EN
M=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI0
M05(Z.D)/3U0["@H@("`@979A;"!["@I?<&%R7VEN:71?96YV*"D["@II9B`H
M97AI<W1S("1%3E9[4$%27T%21U9?,'T@86YD("1%3E9[4$%27T%21U9?,'T@
M*2!["B`@("!`05)'5B`](&UA<"`D14Y6>R)005)?05)'5E\D7R)]+"`H,2`N
M+B`D14Y6>U!!4E]!4D=#?2`M(#$I.PH@("`@)#`@/2`D14Y6>U!!4E]!4D=6
M7S!].PI]"F5L<V4@>PH@("`@9F]R("AK97ES("5%3E8I('L*("`@("`@("!D
M96QE=&4@)$5.5GLD7WT@:68@+UY005)?05)'5E\O.PH@("`@?0I]"@IM>2`D
M<75I970@/2`A)$5.5GM005)?1$5"54=].PH*(R!F:7@@)'!R;V=N86UE(&EF
M(&EN=F]K960@9G)O;2!0051("FUY("5#;VYF:6<@/2`H"B`@("!P871H7W-E
M<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*("`@(%]E
M>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@
M/R`G+F5X92<@.B`G)RDL"B`@("!?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>
M35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PH*7W-E=%]P<F]G;F%M92@I
M.PI?<V5T7W!A<E]T96UP*"D["@HC($UA9VEC('-T<FEN9R!C:&5C:VEN9R!A
M;F0@97AT<F%C=&EN9R!B=6YD;&5D(&UO9'5L97,@>WM["FUY("@D<W1A<G1?
M<&]S+"`D9&%T85]P;W,I.PI["B`@("!L;V-A;"`D4TE'>U]?5T%23E]??2`]
M('-U8B![?3L*"B`@("`C($-H96-K(&9I;&4@='EP92P@9V5T('-T87)T(&]F
M(&1A=&$@<V5C=&EO;B![>WL*("`@(&]P96X@7T9(+"`G/"<L("1P<F]G;F%M
M92!O<B!L87-T.PH@("`@8FEN;6]D92A?1D@I.PH*("`@(&UY("1B=68["B`@
M("!S965K(%]&2"P@+3@L(#(["B`@("!R96%D(%]&2"P@)&)U9BP@.#L*("`@
M(&QA<W0@=6YL97-S("1B=68@97$@(EQN4$%2+G!M7&XB.PH*("`@('-E96L@
M7T9(+"`M,3(L(#(["B`@("!R96%D(%]&2"P@)&)U9BP@-#L*("`@('-E96L@
M7T9(+"`M,3(@+2!U;G!A8VLH(DXB+"`D8G5F*2P@,CL*("`@(')E860@7T9(
M+"`D8G5F+"`T.PH*("`@("1D871A7W!O<R`]("AT96QL(%]&2"D@+2`T.PH@
M("`@(R!]?7T*"B`@("`C($5X=')A8W1I;F<@96%C:"!F:6QE(&EN=&\@;65M
M;W)Y('M[>PH@("`@;7D@)7)E<75I<F5?;&ES=#L*("`@('=H:6QE("@D8G5F
M(&5Q(")&24Q%(BD@>PH@("`@("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@
M("`@(')E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*"B`@("`@
M("`@;7D@)&9U;&QN86UE(#T@)&)U9CL*("`@("`@("!O=71S*'%Q*%5N<&%C
M:VEN9R!F:6QE("(D9G5L;&YA;64B+BXN*2D["B`@("`@("`@;7D@)&-R8R`]
M("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U
M;F1E9CL*("`@("`@("!M>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^
M(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["@H@("`@("`@(')E860@7T9(+"`D
M8G5F+"`T.PH@("`@("`@(')E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D
M8G5F*3L*"B`@("`@("`@:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@
M+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["B`@("`@("`@("`@(&UY("@D;W5T
M+"`D9FEL96YA;64I(#T@7W1E;7!F:6QE*"1E>'0L("1C<F,I.PH@("`@("`@
M("`@("!I9B`H)&]U="D@>PH@("`@("`@("`@("`@("`@8FEN;6]D92@D;W5T
M*3L*("`@("`@("`@("`@("`@('!R:6YT("1O=70@)&)U9CL*("`@("`@("`@
M("`@("`@(&-L;W-E("1O=70["B`@("`@("`@("`@("`@("!C:&UO9"`P-S4U
M+"`D9FEL96YA;64["B`@("`@("`@("`@('T*("`@("`@("`@("`@)%!!4CHZ
M2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PH@("`@
M("`@("`@("`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D
M9G5L;&YA;64["B`@("`@("`@?0H@("`@("`@(&5L<VEF("@@)&9U;&QN86UE
M(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0?2`I
M('L*("`@("`@("`@("`@(R!S:&]U;&0@8F4@;6]V960@=&\@7W1E;7!F:6QE
M*"D*("`@("`@("`@("`@;7D@)&9I;&5N86UE(#T@(B1%3E9[4$%27U1%35!]
M+R1B87-E;F%M921E>'0B.PH@("`@("`@("`@("!O=71S*")32$Q)0CH@)&9I
M;&5N86UE7&XB*3L*("`@("`@("`@("`@;W!E;B!M>2`D;W5T+"`G/B<L("1F
M:6QE;F%M92!O<B!D:64@)"$["B`@("`@("`@("`@(&)I;FUO9&4H)&]U="D[
M"B`@("`@("`@("`@('!R:6YT("1O=70@)&)U9CL*("`@("`@("`@("`@8VQO
M<V4@)&]U=#L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@
M("1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2`]"B`@("`@("`@("`@("1005(Z
M.DAE879Y.CI-;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PH@("`@("`@("`@
M("`@("`@8G5F(#T^("1B=68L"B`@("`@("`@("`@("`@("!C<F,@/3X@)&-R
M8RP*("`@("`@("`@("`@("`@(&YA;64@/3X@)&9U;&QN86UE+`H@("`@("`@
M("`@("!].PH@("`@("`@('T*("`@("`@("!R96%D(%]&2"P@)&)U9BP@-#L*
M("`@('T*("`@(",@?7U]"@H@("`@;&]C86P@0$E.0R`]("AS=6(@>PH@("`@
M("`@(&UY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*"B`@("`@("`@<F5T=7)N
M(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PH*("`@("`@("!M>2`D9FEL
M96YA;64@/2!D96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?2!\?"!D;R![
M"B`@("`@("`@("`@(&UY("1K97D["B`@("`@("`@("`@(&9O<F5A8V@@*&ME
M>7,@)7)E<75I<F5?;&ES="D@>PH@("`@("`@("`@("`@("`@;F5X="!U;FQE
M<W,@+UQ1)&UO9'5L95Q%)"\["B`@("`@("`@("`@("`@("`D:V5Y(#T@)%\[
M(&QA<W0["B`@("`@("`@("`@('T*("`@("`@("`@("`@9&5L971E("1R97%U
M:7)E7VQI<W1[)&ME>7T@:68@9&5F:6YE9"@D:V5Y*3L*("`@("`@("!](&]R
M(')E='5R;CL*"B`@("`@("`@)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1F
M:6QE;F%M92\D;6]D=6QE(CL*"B`@("`@("`@:68@*"1%3E9[4$%27T-,14%.
M?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*("`@("`@("`@("`@
M;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`D(3L*("`@
M("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@("`@("!P<FEN="`D9F@@
M)&9I;&5N86UE+3Y[8G5F?3L*("`@("`@("`@("`@<V5E:R@D9F@L(#`L(#`I
M.PH@("`@("`@("`@("!R971U<FX@)&9H.PH@("`@("`@('T*("`@("`@("!E
M;'-E('L*("`@("`@("`@("`@;7D@*"1O=70L("1N86UE*2`](%]T96UP9FEL
M92@G+G!M)RP@)&9I;&5N86UE+3Y[8W)C?2D["B`@("`@("`@("`@(&EF("@D
M;W5T*2!["B`@("`@("`@("`@("`@("!B:6YM;V1E*"1O=70I.PH@("`@("`@
M("`@("`@("`@<')I;G0@)&]U="`D9FEL96YA;64M/GMB=69].PH@("`@("`@
M("`@("`@("`@8VQO<V4@)&]U=#L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!O<&5N(&UY("1F:"P@)SPG+"`D;F%M92!O<B!D:64@)"$["B`@("`@("`@
M("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@("`@<F5T=7)N("1F:#L*("`@
M("`@("!]"@H@("`@("`@(&1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A
M;FYO="!F:6YD("1M;V1U;&4A7&XB.PH@("`@?2P@0$E.0RD["@H@("`@(R!.
M;W<@;&]A9"!A;&P@8G5N9&QE9"!F:6QE<R![>WL*"B`@("`C(&EN:71I86QI
M>F4@<VAA<F5D(&]B:F5C="!P<F]C97-S:6YG"B`@("!R97%U:7)E(%A33&]A
M9&5R.PH@("`@<F5Q=6ER92!005(Z.DAE879Y.PH@("`@<F5Q=6ER92!#87)P
M.CI(96%V>3L*("`@(')E<75I<F4@17AP;W)T97(Z.DAE879Y.PH@("`@4$%2
M.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PH*("`@(",@;F]W(&QE="=S
M('1R>2!G971T:6YG(&AE;'!E<B!M;V1U;&5S(&9R;VT@=VET:&EN"B`@("!R
M97%U:7)E($E/.CI&:6QE.PH*("`@(",@;&]A9"!R97-T(&]F('1H92!G<F]U
M<"!I;@H@("`@=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E
M<75I<F5?;&ES="E;,%TI('L*("`@("`@("`C;&]C86P@)$E.0WLG0W=D+G!M
M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH@("`@("`@('5N
M;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.
M+RD@>PH@("`@("`@("`@("`C(')E<75I<F4@;6]D=6QE<RP@9&\@;W1H97(@
M97AE8W5T86)L92!F:6QE<PH@("`@("`@("`@("!I9B`H)&9I;&5N86UE(#U^
M("]<+G!M8S\D+VDI('L*("`@("`@("`@("`@("`@(')E<75I<F4@)&9I;&5N
M86UE.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<V4@>PH@("`@("`@
M("`@("`@("`@(R!3:VEP($%C=&EV95-T871E)W,@<VET96-U<W1O;6EZ92YP
M;"!F:6QE.@H@("`@("`@("`@("`@("`@9&\@)&9I;&5N86UE('5N;&5S<R`D
M9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["B`@("`@("`@("`@
M('T*("`@("`@("!]"B`@("`@("`@9&5L971E("1R97%U:7)E7VQI<W1[)&9I
M;&5N86UE?3L*("`@('T*"B`@("`C('U]?0H*("`@(&QA<W0@=6YL97-S("1B
M=68@97$@(E!+7#`P,UPP,#0B.PH@("`@)'-T87)T7W!O<R`]("AT96QL(%]&
M2"D@+2`T.PI]"B,@?7U]"@HC($%R9W5M96YT('!R;V-E<W-I;F<@>WM["FUY
M($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE
M7VYA;64I.PH*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I
M>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"@HD<75I970@
M/2`P('5N;&5S<R`D14Y6>U!!4E]$14)51WT["B,@1&]N)W0@<W=A;&QO=R!A
M<F=U;65N=',@9F]R(&-O;7!I;&5D(&5X96-U=&%B;&5S('=I=&AO=70@+2UP
M87(M;W!T:6]N<PII9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M
M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*("`@(&UY("5D:7-T7V-M9"`]
M('%W*`H@("`@("`@('`@("!B;&EB7W1O7W!A<@H@("`@("`@(&D@("!I;G-T
M86QL7W!A<@H@("`@("`@('4@("!U;FEN<W1A;&Q?<&%R"B`@("`@("`@<R`@
M('-I9VY?<&%R"B`@("`@("`@=B`@('9E<FEF>5]P87(*("`@("D["@H@("`@
M(R!I9B!T:&4@87!P(&ES(&EN=F]K960@87,@(F%P<&YA;64@+2UP87(M;W!T
M:6]N<R`M+7)E=7-E(%!23T=204T@0%!23T=?05)'5B(L"B`@("`C('5S92!T
M:&4@87!P('1O(')U;B!T:&4@9VEV96X@<&5R;"!C;V1E(&EN<W1E860@;V8@
M86YY=&AI;F<@9G)O;2!T:&4*("`@(",@87!P(&ET<V5L9B`H8G5T('-T:6QL
M('-E="!U<"!T:&4@;F]R;6%L(&%P<"!E;G9I<F]N;65N="!A;F0@0$E.0RD*
M("`@(&EF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["B`@
M("`@("`@<VAI9G0@0$%21U8["B`@("`@("`@)$5.5GM005)?05!07U)%55-%
M?2`]('-H:69T($!!4D=6.PH@("`@?0H@("`@96QS92![(",@;F]R;6%L('!A
M<FP@8F5H879I;W5R"@H@("`@("`@(&UY($!A9&1?=&]?:6YC.PH@("`@("`@
M('=H:6QE("A`05)'5BD@>PH@("`@("`@("`@("`D05)'5ELP72`]?B`O7BTH
M6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PH*("`@("`@("`@("`@
M:68@*"0Q(&5Q("=))RD@>PH@("`@("`@("`@("`@("`@<'5S:"!`861D7W1O
M7VEN8RP@)#(["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q
M(&5Q("=-)RD@>PH@("`@("`@("`@("`@("`@979A;"`B=7-E("0R(CL*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)T$G*2!["B`@
M("`@("`@("`@("`@("!U;G-H:69T($!P87)?87)G<RP@)#(["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=/)RD@>PH@("`@("`@
M("`@("`@("`@)&]U="`]("0R.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&5L<VEF("@D,2!E<2`G8B<I('L*("`@("`@("`@("`@("`@("1B=6YD;&4@
M/2`G<VET92<["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q
M(&5Q("=")RD@>PH@("`@("`@("`@("`@("`@)&)U;F1L92`]("=A;&PG.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G<2<I('L*
M("`@("`@("`@("`@("`@("1Q=6EE="`](#$["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@96QS:68@*"0Q(&5Q("=,)RD@>PH@("`@("`@("`@("`@("`@
M;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92`B6%A8.B!#86YN;W0@;W!E
M;B!L;V<Z("0A(CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H
M)#$@97$@)U0G*2!["B`@("`@("`@("`@("`@("`D8V%C:&5?;F%M92`]("0R
M.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!S:&EF="A`05)'5BD["@H@
M("`@("`@("`@("!I9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*("`@
M("`@("`@("`@("`@(&1E;&5T92`D14Y6>R=005)?5$5-4"=].PH@("`@("`@
M("`@("`@("`@:6YI=%]I;F,H*3L*("`@("`@("`@("`@("`@(')E<75I<F4@
M4$%2.CI$:7-T.PH@("`@("`@("`@("`@("`@)GLB4$%2.CI$:7-T.CHD8VUD
M(GTH*2!U;FQE<W,@0$%21U8["B`@("`@("`@("`@("`@("`F>R)005(Z.D1I
M<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PH@("`@("`@("`@("`@("`@97AI
M=#L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@=6YS:&EF="!`
M24Y#+"!`861D7W1O7VEN8SL*("`@('T*?0H*(R!86%@@+2T@861D("TM<&%R
M+61E8G5G('-U<'!O<G0A"@HC('U]?0H*(R!/=71P=70@;6]D92`H+4\I(&AA
M;F1L:6YG('M[>PII9B`H)&]U="D@>PH@("`@>PH@("`@("`@("-L;V-A;"`D
M24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>3R!N92`G35-7:6XS,B<[
M"B`@("`@("`@<F5Q=6ER92!)3SHZ1FEL93L*("`@("`@("!R97%U:7)E($%R
M8VAI=F4Z.EII<#L*("`@('T*"B`@("!M>2`D<&%R(#T@<VAI9G0H0$%21U8I
M.PH@("`@;7D@)'II<#L*"@H@("`@:68@*&1E9FEN960@)'!A<BD@>PH@("`@
M("`@(&]P96X@;7D@)&9H+"`G/"<L("1P87(@;W(@9&EE(")#86YN;W0@9FEN
M9"`G)'!A<B<Z("0A(CL*("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@
M8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*"B`@("`@("`@)'II<"`]($%R8VAI
M=F4Z.EII<"T^;F5W.PH@("`@("`@("@@)'II<"T^<F5A9$9R;VU&:6QE2&%N
M9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*("`@
M("`@("`@("`@;W(@9&EE(")296%D("<D<&%R)R!E<G)O<CH@)"$B.PH@("`@
M?0H*"B`@("!M>2`E96YV(#T@9&\@>PH@("`@("`@(&EF("@D>FEP(&%N9"!M
M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B`@("`@
M("`@("`@("1M971A(#U^(',O+BI><&%R.B0O+VUS.PH@("`@("`@("`@("`D
M;65T82`]?B!S+UY<4RXJ+R]M<SL*("`@("`@("`@("`@)&UE=&$@/7X@+UX@
M("A;7CI=*RDZ("@N*RDD+VUG.PH@("`@("`@('T*("`@('T["@H@("`@(R!/
M<&5N(&EN<'5T(&%N9"!O=71P=70@9FEL97,@>WM["B`@("!L;V-A;"`D+R`]
M(%PT.PH*("`@(&EF("AD969I;F5D("1P87(I('L*("`@("`@("!O<&5N(%!!
M4BP@)SPG+"`D<&%R(&]R(&1I92`B)"$Z("1P87(B.PH@("`@("`@(&)I;FUO
M9&4H4$%2*3L*("`@("`@("!D:64@(B1P87(@:7,@;F]T(&$@4$%2(&9I;&4B
M('5N;&5S<R`\4$%2/B!E<2`B4$M<,#`S7#`P-"(["B`@("!]"@H@("`@0W)E
M871E4&%T:"@D;W5T*2`["B`@("`*("`@(&UY("1F:"`]($E/.CI&:6QE+3YN
M97<H"B`@("`@("`@)&]U="P*("`@("`@("!)3SHZ1FEL93HZ3U]#4D5!5"@I
M('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I
M+`H@("`@("`@(#`W-S<L"B`@("`I(&]R(&1I92`D(3L*("`@(&)I;FUO9&4H
M)&9H*3L*"B`@("`D+R`]("AD969I;F5D("1D871A7W!O<RD@/R!<)&1A=&%?
M<&]S(#H@=6YD968["B`@("!S965K(%]&2"P@,"P@,#L*("`@(&UY("1L;V%D
M97(@/2!S8V%L87(@/%]&2#X["B`@("!I9B`H(21%3E9[4$%27U9%4D)!5$E-
M?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*("`@("`@("!R
M97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*("`@("`@("!005(Z.D9I
M;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1L;V%D97(L("0P*0H@("`@
M?0H@("`@9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@>PH@("`@
M("`@(&UY("1V86P@/2`D96YV>R1K97E](&]R(&YE>'0["B`@("`@("`@)'9A
M;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\["B`@("`@("`@;7D@
M)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B.PH@("`@
M("`@(&UY("1S970@/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A;"(["B`@
M("`@("`@)&QO861E<B`]?B!S>R1M86=I8R@@*RE]>PH@("`@("`@("`@("`D
M;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL96YG=&@H)#$I("T@;&5N9W1H*"1S
M970I*2D*("`@("`@("!]96<["B`@("!]"B`@("`D9F@M/G!R:6YT*"1L;V%D
M97(I.PH@("`@)"\@/2!U;F1E9CL*("`@(",@?7U]"@H@("`@(R!7<FET92!B
M=6YD;&5D(&UO9'5L97,@>WM["B`@("!I9B`H)&)U;F1L92D@>PH@("`@("`@
M(')E<75I<F4@4$%2.CI(96%V>3L*("`@("`@("!005(Z.DAE879Y.CI?:6YI
M=%]D>6YA;&]A9&5R*"D["B`@("`@("`@:6YI=%]I;F,H*3L*"B`@("`@("`@
M<F5Q=6ER95]M;V1U;&5S*"D["@H@("`@("`@(&UY($!I;F,@/2!S;W)T('L*
M("`@("`@("`@("`@;&5N9W1H*"1B*2`\/3X@;&5N9W1H*"1A*0H@("`@("`@
M('T@9W)E<"!["B`@("`@("`@("`@("$O0E-$4$%.+PH@("`@("`@('T@9W)E
M<"!["B`@("`@("`@("`@("@D8G5N9&QE(&YE("=S:71E)RD@;W(*("`@("`@
M("`@("`@*"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*
M("`@("`@("`@("`@("1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP
M?2D["B`@("`@("`@?2!`24Y#.PH*("`@("`@("!I9B`H)$-O;F9I9WM?9&5L
M:6U](&5Q("=<7"<I('L@<WM<7'U[+WUG(&9O<B!`:6YC('T*"B`@("`@("`@
M(R!&:6QE(&5X:7-T<R!T97-T(&%D9&5D('1O(&9I>"!25"`C-#$W.3`Z"B`@
M("`@("`@(R!&=6YN>2P@;F]N+65X:7-T:6YG(&5N=')Y(&EN(%\\+BXN+F%U
M=&\O0V]M<')E<W,O4F%W+UIL:6(O875T;W-P;&ET+FEX+@H@("`@("`@(",@
M5&AI<R!I<R!A(&)A;F0M86ED(&9I>"!W:71H(&YO(&1E97!E<B!G<F%S<"!O
M9B!T:&4@:7-S=64N"B`@("`@("`@(R!3;VUE8F]D>2!P;&5A<V4@9V\@=&AR
M;W5G:"!T:&4@<&%I;B!O9B!U;F1E<G-T86YD:6YG('=H870G<R!H87!P96YI
M;F<L"B`@("`@("`@(R!)(&9A:6QE9"X@+2T@4W1E9F9E;@H@("`@("`@(&UY
M("5F:6QE<SL*("`@("`@("`O7E\\*"XK*20O(&%N9"`M92`D,2!A;F0@)&9I
M;&5S>R0Q?2LK(&9O<B!K97ES("4Z.CL*("`@("`@("`D9FEL97-[)%]]*RL@
M9F]R('9A;'5E<R`E24Y#.PH*("`@("`@("!M>2`D;&EB7V5X="`]("1#;VYF
M:6<Z.D-O;F9I9WML:6)?97AT?3L*("`@("`@("!M>2`E=W)I='1E;CL*"B`@
M("`@("`@9F]R96%C:"`H<V]R="!K97ES("5F:6QE<RD@>PH@("`@("`@("`@
M("!M>2`H)&YA;64L("1F:6QE*3L*"B`@("`@("`@("`@(&9O<F5A8V@@;7D@
M)&1I<B`H0&EN8RD@>PH@("`@("`@("`@("`@("`@:68@*"1N86UE(#T@)%!!
M4CHZ2&5A=GDZ.D9U;&Q#86-H97LD7WTI('L*("`@("`@("`@("`@("`@("`@
M("`D9FEL92`]("1?.PH@("`@("`@("`@("`@("`@("`@(&QA<W0["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!E;'-I9B`H+UXH7%$D9&ER
M7$5<+R@N*EM>0V-=*2E<6B]I*2!["B`@("`@("`@("`@("`@("`@("`@*"1F
M:6QE+"`D;F%M92D@/2`H)#$L("0R*3L*("`@("`@("`@("`@("`@("`@("!L
M87-T.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@96QS:68@
M*&TA7B]L;V%D97(O6UXO72LO*"XJ6UY#8UTI7%HA*2!["B`@("`@("`@("`@
M("`@("`@("`@:68@*&UY("1R968@/2`D4$%2.CI(96%V>3HZ36]D=6QE0V%C
M:&5[)#%]*2!["B`@("`@("`@("`@("`@("`@("`@("`@("@D9FEL92P@)&YA
M;64I(#T@*"1R968L("0Q*3L*("`@("`@("`@("`@("`@("`@("`@("`@;&%S
M=#L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@
M96QS:68@*"UF("(D9&ER+R0Q(BD@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`H)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*("`@("`@("`@
M("`@("`@("`@("`@("`@;&%S=#L*("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&YE
M>'0@=6YL97-S(&1E9FEN960@)&YA;64@86YD(&YO="`D=W)I='1E;GLD;F%M
M97TK*SL*("`@("`@("`@("`@;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I
M;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"\["B`@("`@("`@("`@(&]U=',H(&IO
M:6X@(B(L"B`@("`@("`@("`@("`@("!Q<2A086-K:6YG("(I+"!R968@)&9I
M;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4L"B`@("`@("`@("`@("`@("!Q
M<2@B+BXN*0H@("`@("`@("`@("`I.PH*("`@("`@("`@("`@;7D@)&-O;G1E
M;G0["B`@("`@("`@("`@(&EF("AR968H)&9I;&4I*2!["B`@("`@("`@("`@
M("`@("`D8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!E;'-E('L*("`@("`@("`@("`@("`@(&]P96X@1DE,12P@
M)SPG+"`D9FEL92!O<B!D:64@(D-A;B=T(&]P96X@)&9I;&4Z("0A(CL*("`@
M("`@("`@("`@("`@(&)I;FUO9&4H1DE,12D["B`@("`@("`@("`@("`@("`D
M8V]N=&5N="`](#Q&24Q%/CL*("`@("`@("`@("`@("`@(&-L;W-E($9)3$4[
M"@H@("`@("`@("`@("`@("`@4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M
M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4I"B`@("`@("`@("`@("`@("`@("`@
M:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\
M:7A\86PI)"]I.PH*("`@("`@("`@("`@("`@(",@1&\@;F]T(&QE="!84TQO
M861E<B!P:6-K('5P(&%U=&\O*B!F<F]M(&5N=FER;VYM96YT"B`@("`@("`@
M("`@("`@("`D8V]N=&5N="`]?B!S+V=O=&\@*W)E=')Y("MU;FQE<W,@*RXJ
M+V=O=&\@<F5T<GD[+PH@("`@("`@("`@("`@("`@("`@(&EF(&QC*"1N86UE
M*2!E<2!L8R@B6%-,;V%D97(N<&TB*3L*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@;W5T<RAQ<2A7<FET=&5N(&%S("(D;F%M92(I*3L*("`@("`@("`@
M("`@)&9H+3YP<FEN="@B1DE,12(I.PH@("`@("`@("`@("`D9F@M/G!R:6YT
M*'!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DI.PH@("`@("`@("`@("`D
M9F@M/G!R:6YT*'-P<FEN=&8H"B`@("`@("`@("`@("`@("`B)3`X>"\E<R(L
M($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64*
M("`@("`@("`@("`@*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H<&%C:R@G
M3B<L(&QE;F=T:"@D8V]N=&5N="DI*3L*("`@("`@("`@("`@)&9H+3YP<FEN
M="@D8V]N=&5N="D["B`@("`@("`@?0H@("`@?0H@("`@(R!]?7T*"B`@("`C
M($YO=R!W<FET92!O=70@=&AE(%!!4B!A;F0@;6%G:6,@<W1R:6YG<R![>WL*
M("`@("1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@)'II<#L*"B`@
M("`D8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`["B`@
M("!I9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T
M*2E;.5TI('L*("`@("`@("!M>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG
M97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0H@("`@("`@("`@("!\
M?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^
M;F5W('T*("`@("`@("`@("`@?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-
M1#4[($1I9V5S=#HZ340U+3YN97<@?3L*"B`@("`@("`@(R!7;W)K87)O=6YD
M(&9O<B!B=6<@:6X@1&EG97-T.CI32$$@-2XS."!A;F0@-2XS.0H@("`@("`@
M(&UY("1S:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)
M3TX@?2!\?"`P.PH@("`@("`@(&EF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G
M(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*("`@("`@("`@("`@)&-T
M>"T^861D9FEL92@D;W5T+"`B8B(I(&EF("@D8W1X*3L*("`@("`@("!]"B`@
M("`@("`@96QS92!["B`@("`@("`@("`@(&EF("@D8W1X(&%N9"!O<&5N*&UY
M("1F:"P@(CPD;W5T(BDI('L*("`@("`@("`@("`@("`@(&)I;FUO9&4H)&9H
M*3L*("`@("`@("`@("`@("`@("1C='@M/F%D9&9I;&4H)&9H*3L*("`@("`@
M("`@("`@("`@(&-L;W-E*"1F:"D["B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@("1C86-H95]N86UE(#T@)&-T>"`_("1C='@M/FAE>&1I9V5S
M="`Z("1M=&EM93L*("`@('T*("`@("1C86-H95]N86UE("X](")<,"(@>"`H
M-#$@+2!L96YG=&@@)&-A8VAE7VYA;64I.PH@("`@)&-A8VAE7VYA;64@+CT@
M(D-!0TA%(CL*("`@("1F:"T^<')I;G0H)&-A8VAE7VYA;64I.PH@("`@)&9H
M+3YP<FEN="AP86-K*"=.)RP@)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D97(I
M*2D["B`@("`D9F@M/G!R:6YT*")<;E!!4BYP;5QN(BD["B`@("`D9F@M/F-L
M;W-E.PH@("`@8VAM;V0@,#<U-2P@)&]U=#L*("`@(",@?7U]"@H@("`@97AI
M=#L*?0HC('U]?0H*(R!0<F5P87)E("1P<F]G;F%M92!I;G1O(%!!4B!F:6QE
M(&-A8VAE('M[>PI["B`@("!L87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P
M;W,["@H@("`@7V9I>%]P<F]G;F%M92@I.PH*("`@(",@3F]W(&QO860@=&AE
M(%!!4B!F:6QE(&%N9"!P=70@:70@:6YT;R!005(Z.DQI8D-A8VAE('M[>PH@
M("`@<F5Q=6ER92!005(["B`@("!005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A
M9&5R*"D["@H*("`@('L*("`@("`@("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@
M/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH@("`@("`@(')E<75I
M<F4@1FEL93HZ1FEN9#L*("`@("`@("!R97%U:7)E($%R8VAI=F4Z.EII<#L*
M("`@('T*("`@(&UY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*("`@(&UY
M("1F:"`]($E/.CI&:6QE+3YN97<["B`@("`D9F@M/F9D;W!E;BAF:6QE;F\H
M7T9(*2P@)W(G*2!O<B!D:64@(B0A.B`D0"(["B`@("`D>FEP+3YR96%D1G)O
M;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ
M05I?3TLH*2!O<B!D:64@(B0A.B`D0"(["@H@("`@<'5S:"!`4$%2.CI,:6)#
M86-H92P@)'II<#L*("`@("1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D
M>FEP.PH*("`@("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["B`@("!O=71S
M*'%Q*%PD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2(I*3L*"B`@
M("!I9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S
M970@870@=&AI<R!P;VEN="$*("`@("`@("!F;W)E86-H(&UY("1M96UB97(@
M*"`D>FEP+3YM96UB97)S("D@>PH@("`@("`@("`@("!N97AT(&EF("1M96UB
M97(M/FES1&ER96-T;W)Y.PH@("`@("`@("`@("!M>2`D;65M8F5R7VYA;64@
M/2`D;65M8F5R+3YF:6QE3F%M93L*("`@("`@("`@("`@;F5X="!U;FQE<W,@
M)&UE;6)E<E]N86UE(#U^(&U["B`@("`@("`@("`@("`@("!>"B`@("`@("`@
M("`@("`@("`O/W-H;&EB+PH@("`@("`@("`@("`@("`@*#\Z)$-O;F9I9SHZ
M0V]N9FEG>W9E<G-I;VY]+RD_"B`@("`@("`@("`@("`@("`H/SHD0V]N9FEG
M.CI#;VYF:6=[87)C:&YA;65]+RD_"B`@("`@("`@("`@("`@("`H6UXO72LI
M"B`@("`@("`@("`@("`@("`D"B`@("`@("`@("`@('UX.PH@("`@("`@("`@
M("!M>2`D97AT<F%C=%]N86UE(#T@)#$["B`@("`@("`@("`@(&UY("1D97-T
M7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D
M97AT<F%C=%]N86UE*3L*("`@("`@("`@("`@:68@*"UF("1D97-T7VYA;64@
M)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*("`@
M("`@("`@("`@("`@(&]U=',H<7$H4VMI<'!I;F<@(B1M96UB97)?;F%M92(@
M<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B*2D["B`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!O=71S*'%Q*$5X
M=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B*2D["B`@
M("`@("`@("`@("`@("`D;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E
M<W1?;F%M92D["B`@("`@("`@("`@("`@("!C:&UO9"@P-34U+"`D9&5S=%]N
M86UE*2!I9B`D7D\@97$@(FAP=7@B.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H@("`@?0H@("`@(R!]?7T*?0HC('U]?0H*(R!)9B!T:&5R92=S(&YO(&UA
M:6XN<&P@=&\@<G5N+"!S:&]W('5S86=E('M[>PIU;FQE<W,@*"1005(Z.DQI
M8D-A8VAE>R1P<F]G;F%M97TI('L*("`@(&1I92`\/"`B+B(@=6YL97-S($!!
M4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO
M9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B`@("`@("`D,"!;
M("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B`@("`D14Y6>U!!4E]0
M4D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0HC
M('U]?0H*<W5B($-R96%T95!A=&@@>PH@("`@;7D@*"1N86UE*2`]($!?.PH@
M("`@"B`@("!R97%U:7)E($9I;&4Z.D)A<V5N86UE.PH@("`@;7D@*"1B87-E
M;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S
M92@D;F%M92P@*"=<+BXJ)RDI.PH@("`@"B`@("!R97%U:7)E($9I;&4Z.E!A
M=&@["B`@("`*("`@($9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S
M*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*"G-U8B!R
M97%U:7)E7VUO9'5L97,@>PH@("`@(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@
M7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*"B`@("!R97%U:7)E(&QI
M8CL*("`@(')E<75I<F4@1'EN84QO861E<CL*("`@(')E<75I<F4@:6YT96=E
M<CL*("`@(')E<75I<F4@<W1R:6-T.PH@("`@<F5Q=6ER92!W87)N:6YG<SL*
M("`@(')E<75I<F4@=F%R<SL*("`@(')E<75I<F4@0V%R<#L*("`@(')E<75I
M<F4@0V%R<#HZ2&5A=GD["B`@("!R97%U:7)E($5R<FYO.PH@("`@<F5Q=6ER
M92!%>'!O<G1E<CHZ2&5A=GD["B`@("!R97%U:7)E($5X<&]R=&5R.PH@("`@
M<F5Q=6ER92!&8VYT;#L*("`@(')E<75I<F4@1FEL93HZ5&5M<#L*("`@(')E
M<75I<F4@1FEL93HZ4W!E8SL*("`@(')E<75I<F4@6%-,;V%D97(["B`@("!R
M97%U:7)E($-O;F9I9SL*("`@(')E<75I<F4@24\Z.DAA;F1L93L*("`@(')E
M<75I<F4@24\Z.D9I;&4["B`@("!R97%U:7)E($-O;7!R97-S.CI:;&EB.PH@
M("`@<F5Q=6ER92!!<F-H:79E.CI::7`["B`@("!R97%U:7)E(%!!4CL*("`@
M(')E<75I<F4@4$%2.CI(96%V>3L*("`@(')E<75I<F4@4$%2.CI$:7-T.PH@
M("`@<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["B`@("!E=F%L('L@
M<F5Q=6ER92!#=V0@?3L*("`@(&5V86P@>R!R97%U:7)E(%=I;C,R('T["B`@
M("!E=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*("`@(&5V86P@>R!R
M97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PH@("`@979A;"![(')E
M<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*?0H*(R!4:&4@0R!V
M97)S:6]N(&]F('1H:7,@8V]D92!A<'!E87)S(&EN(&UY;&1R+VUK=&UP9&ER
M+F,*(R!4:&ES(&-O9&4@86QS;R!L:79E<R!I;B!005(Z.E-E='5P5&5M<"!A
M<R!S971?<&%R7W1E;7!?96YV(0IS=6(@7W-E=%]P87)?=&5M<"!["B`@("!I
M9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@
M/7X@+R@N*RDO*2!["B`@("`@("`@)'!A<E]T96UP(#T@)#$["B`@("`@("`@
M<F5T=7)N.PH@("`@?0H*("`@(&9O<F5A8V@@;7D@)'!A=&@@*`H@("`@("`@
M("AM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2
M(%1%35`@5$U0("DI+`H@("`@("`@('%W*"!#.EQ<5$5-4"`O=&UP("X@*0H@
M("`@*2!["B`@("`@("`@;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@
M+60@)'!A=&@@86YD("UW("1P871H.PH@("`@("`@(&UY("1U<V5R;F%M93L*
M("`@("`@("!M>2`D<'=U:60["B`@("`@("`@(R!D;V5S(&YO="!W;W)K(&5V
M97)Y=VAE<F4Z"B`@("`@("`@979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D
M/BD@:68@9&5F:6YE9"`D/CM].PH*("`@("`@("!I9B`H(&1E9FEN960H)E=I
M;C,R.CI,;V=I;DYA;64I("D@>PH@("`@("`@("`@("`D=7-E<FYA;64@/2`F
M5VEN,S(Z.DQO9VEN3F%M93L*("`@("`@("!]"B`@("`@("`@96QS:68@*&1E
M9FEN960@)'!W=6ED*2!["B`@("`@("`@("`@("1U<V5R;F%M92`]("1P=W5I
M9#L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@("1U<V5R
M;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%
M32<["B`@("`@("`@?0H@("`@("`@("1U<V5R;F%M92`]?B!S+UQ7+U\O9SL*
M"B`@("`@("`@;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP
M87(M)'5S97)N86UE(CL*("`@("`@("!M:V1I<B`D<W1M<&1I<BP@,#<U-3L*
M("`@("`@("!I9B`H(21%3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE(#T@
M*'-T870H)'!R;V=N86UE*2E;.5TI('L*("`@("`@("`@("`@;W!E;B`H;7D@
M)&9H+"`B/"(N("1P<F]G;F%M92D["B`@("`@("`@("`@('-E96L@)&9H+"`M
M,3@L(#(["B`@("`@("`@("`@('-Y<W)E860@)&9H+"!M>2`D8G5F+"`V.PH@
M("`@("`@("`@("!I9B`H)&)U9B!E<2`B7#!#04-(12(I('L*("`@("`@("`@
M("`@("`@('-E96L@)&9H+"`M-3@L(#(["B`@("`@("`@("`@("`@("!S>7-R
M96%D("1F:"P@)&)U9BP@-#$["B`@("`@("`@("`@("`@("`D8G5F(#U^(',O
M7#`O+V<["B`@("`@("`@("`@("`@("`D<W1M<&1I<B`N/2`B)$-O;F9I9WM?
M9&5L:6U]8V%C:&4M(B`N("1B=68["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@96QS92!["B`@("`@("`@("`@("`@("!M>2`D8W1X(#T@979A;"![(')E
M<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0H@("`@
M("`@("`@("`@("`@("`@('Q\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!
M,3L@1&EG97-T.CI32$$Q+3YN97<@?0H@("`@("`@("`@("`@("`@("`@('Q\
M(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W
M('T["@H@("`@("`@("`@("`@("`@(R!7;W)K87)O=6YD(&9O<B!B=6<@:6X@
M1&EG97-T.CI32$$@-2XS."!A;F0@-2XS.0H@("`@("`@("`@("`@("`@;7D@
M)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]
M('Q\(#`["B`@("`@("`@("`@("`@("!I9B`H)'-H85]V97)S:6]N(&5Q("<U
M+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2!["B`@("`@("`@("`@
M("`@("`@("`@)&-T>"T^861D9FEL92@D<')O9VYA;64L(")B(BD@:68@*"1C
M='@I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@96QS92![
M"B`@("`@("`@("`@("`@("`@("`@:68@*"1C='@@86YD(&]P96XH;7D@)&9H
M+"`B/"1P<F]G;F%M92(I*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&)I
M;FUO9&4H)&9H*3L*("`@("`@("`@("`@("`@("`@("`@("`@)&-T>"T^861D
M9FEL92@D9F@I.PH@("`@("`@("`@("`@("`@("`@("`@("!C;&]S92@D9F@I
M.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("`@("`D<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C
M:&4M(B`N("@@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM92`I.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@(&-L;W-E*"1F:"D["B`@("`@("`@
M?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`D14Y6>U!!4E]#3$5!3GT@
M/2`Q.PH@("`@("`@("`@("`D<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]
M=&5M<"TD)"(["B`@("`@("`@?0H*("`@("`@("`D14Y6>U!!4E]414U0?2`]
M("1S=&UP9&ER.PH@("`@("`@(&UK9&ER("1S=&UP9&ER+"`P-S4U.PH@("`@
M("`@(&QA<W0["B`@("!]"@H@("`@)'!A<E]T96UP(#T@)#$@:68@)$5.5GM0
M05)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0H*<W5B
M(%]T96UP9FEL92!["B`@("!M>2`H)&5X="P@)&-R8RD@/2!`7SL*("`@(&UY
M("@D9F@L("1F:6QE;F%M92D["@H@("`@)&9I;&5N86UE(#T@(B1P87)?=&5M
M<"\D8W)C)&5X="(["@H@("`@:68@*"1%3E9[4$%27T-,14%.?2D@>PH@("`@
M("`@('5N;&EN:R`D9FEL96YA;64@:68@+64@)&9I;&5N86UE.PH@("`@("`@
M('!U<V@@0'1M<&9I;&4L("1F:6QE;F%M93L*("`@('T*("`@(&5L<V4@>PH@
M("`@("`@(')E='5R;B`H=6YD968L("1F:6QE;F%M92D@:68@*"UR("1F:6QE
M;F%M92D["B`@("!]"@H@("`@;W!E;B`D9F@L("<^)RP@)&9I;&5N86UE(&]R
M(&1I92`D(3L*("`@(&)I;FUO9&4H)&9H*3L*("`@(')E='5R;B@D9F@L("1F
M:6QE;F%M92D["GT*"B,@<V%M92!C;V1E(&QI=F5S(&EN(%!!4CHZ4V5T=7!0
M<F]G;F%M93HZ<V5T7W!R;V=N86UE"G-U8B!?<V5T7W!R;V=N86UE('L*("`@
M(&EF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?
M4%)/1TY!345](#U^("\H+BLI+RD@>PH@("`@("`@("1P<F]G;F%M92`]("0Q
M.PH@("`@?0H*("`@("1P<F]G;F%M92!\?#T@)#`["@H@("`@:68@*"1%3E9[
M4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]
M*2`^/2`P*2!["B`@("`@("`@)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M
M92P@<FEN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PH@
M("`@?0H*("`@(&EF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P
M<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^/2`P*2!["B`@("`@("`@:68@
M*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PH@("`@("`@("`@("!R
M971U<FX@:68@+7,@)&9H.PH@("`@("`@('T*("`@("`@("!I9B`H+7,@(B1P
M<F]G;F%M921#;VYF:6=[7V5X97TB*2!["B`@("`@("`@("`@("1P<F]G;F%M
M92`N/2`D0V]N9FEG>U]E>&5].PH@("`@("`@("`@("!R971U<FX["B`@("`@
M("`@?0H@("`@?0H*("`@(&9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O
M;F9I9WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*("`@("`@("!N97AT
M(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!
M4E]414U0?3L*("`@("`@("`D9&ER(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<
M120O+SL*("`@("`@("`H*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L
M:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(I+"!L87-T*0H@("`@("`@("`@
M("!I9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[
M7V5X97TB.PH@("`@("`@("@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D
M96QI;7TD<')O9VYA;64B*2P@;&%S="D*("`@("`@("`@("`@:68@+7,@(B1D
M:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PH@("`@?0I]"@IS=6(@7V9I
M>%]P<F]G;F%M92!["B`@("`D,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?
M4%)/1TY!345].PH@("`@:68@*&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?
M9&5L:6U]*2`\(#`I('L*("`@("`@("`D<')O9VYA;64@/2`B+B1#;VYF:6=[
M7V1E;&EM?21P<F]G;F%M92(["B`@("!]"@H@("`@(R!86%@@+2!H86-K('1O
M(&UA:V4@4%=$('=O<FL*("`@(&UY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG
M971C=V0I(#\@0W=D.CIG971C=V0H*0H@("`@("`@("`@("`@("`@.B`H*&1E
M9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W
M9&`I.PH@("`@8VAO;7`H)'!W9"D["B`@("`D<')O9VYA;64@/7X@<R]>*#\]
M7"Y<+C]<421#;VYF:6=[7V1E;&EM?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]
M+SL*"B`@("`D14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*"G-U
M8B!?<&%R7VEN:71?96YV('L*("`@(&EF("@@)$5.5GM005)?24Y)5$E!3$E:
M141]*RL@/3T@,2`I('L*("`@("`@("!R971U<FX["B`@("!](&5L<V4@>PH@
M("`@("`@("1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["B`@("!]"@H@("`@
M9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.
M04U%($%21T,@05)'5E\P("D@*2!["B`@("`@("`@9&5L971E("1%3E9[)U!!
M4E\G+B1??3L*("`@('T*("`@(&9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.
M($1%0E5'("\I('L*("`@("`@("`D14Y6>R=005)?)RXD7WT@/2`D14Y6>R=0
M05)?1TQ/0D%,7R<N)%]](&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N
M)%]].PH@("`@?0H*("`@(&UY("1P87)?8VQE86X@/2`B7U]%3E9?4$%27T-,
M14%.7U\@("`@("`@("`@("`@("`B.PH*("`@(&EF("@D14Y6>U!!4E]414U0
M?2D@>PH@("`@("`@(&1E;&5T92`D14Y6>U!!4E]#3$5!3GT["B`@("!]"B`@
M("!E;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2!["B`@
M("`@("`@;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R("L@;&5N
M9W1H*")#3$5!3B(I*3L*("`@("`@("`D14Y6>U!!4E]#3$5!3GT@/2`D,2!I
M9B`D=F%L=64@/7X@+UY005)?0TQ%04X]*%Q3*RDO.PH@("`@?0I]"@IS=6(@
M;W5T<R!["B`@("!R971U<FX@:68@)'%U:65T.PH@("`@:68@*"1L;V=F:"D@
M>PH@("`@("`@('!R:6YT("1L;V=F:"`B0%]<;B(["B`@("!]"B`@("!E;'-E
M('L*("`@("`@("!P<FEN="`B0%]<;B(["B`@("!]"GT*"G-U8B!I;FET7VEN
M8R!["B`@("!R97%U:7)E($-O;F9I9SL*("`@('!U<V@@0$E.0RP@9W)E<"!D
M969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"B`@("`@("`@
M87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*
M("`@("`@("!V96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`H@("`@*3L*?0H*
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C"B,@5&AE(&UA:6X@<&%C:V%G
M92!F;W(@<V-R:7!T(&5X96-U=&EO;@H*<&%C:V%G92!M86EN.PH*<F5Q=6ER
M92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM
M<&]R="A`<&%R7V%R9W,I.PH*9&EE('%Q*'!A<BYP;#H@0V%N)W0@;W!E;B!P
M97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C
M=&]R>5QN*0H@("`@=6YL97-S("UE("1P<F]G;F%M93L*"F1O("1P<F]G;F%M
M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI
M7"DO*3L*9&EE("1`(&EF("1`.PH*?3L*"B0Z.E]?15)23U(@/2`D0"!I9B`D
M0#L*?0H*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%
M6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2
M.PH*,3L*"B-L:6YE(#$P,3(*"E]?14Y$7U\*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````____
M_P````#_____```````````!`````0````$```"R`@```0```+T"```!````
MQP(```$````6`P```0```&0$```,````I)<$"`T```#\S00(!````(R!!`CU
M_O]OZ(0$"`4```"`C00(!@```$"&!`@*````!`8```L````0````%0``````
M```#````]#\%"`(```"``@``%````!$````7````))4$"!$````,E00($@``
M`!@````3````"````/[__V]LE`0(____;P(```#P__]OA),$"```````````
M``````````````````````````````````````````````````````````#X
M/@4(``````````#JEP0(^I<$"`J8!`@:F`0(*I@$"#J8!`A*F`0(6I@$"&J8
M!`AZF`0(BI@$")J8!`BJF`0(NI@$",J8!`C:F`0(ZI@$"/J8!`@*F00(&ID$
M""J9!`@ZF00(2ID$"%J9!`AJF00(>ID$"(J9!`B:F00(JID$"+J9!`C*F00(
MVID$".J9!`CZF00("IH$"!J:!`@JF@0(.IH$"$J:!`A:F@0(:IH$"'J:!`B*
MF@0(FIH$"*J:!`BZF@0(RIH$"-J:!`CJF@0(^IH$"`J;!`@:FP0(*IL$"#J;
M!`A*FP0(6IL$"&J;!`AZFP0(BIL$")J;!`BJFP0(NIL$",J;!`C:FP0(ZIL$
M"/J;!`@*G`0(&IP$""J<!`@ZG`0(2IP$"%J<!`AJG`0(>IP$"(J<!`B:G`0(
MJIP$"+J<!`C*G`0(VIP$"```````````_____]#0!`C96P``1T-#.B`H56)U
M;G1U(#0N-"XR+3EU8G5N='4T*2`T+C0N,R`R,#$P,#$Q-B`H<')E<F5L96%S
M92D``"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+D%"22UT86<`+FYO=&4N9VYU
M+F)U:6QD+6ED`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S
M:6]N`"YG;G4N=F5R<VEO;E]R`"YR96PN9'EN`"YR96PN<&QT`"YI;FET`"YT
M97AT`"YF:6YI`"YR;V1A=&$`+F5H7V9R86UE`"YC=&]R<P`N9'1O<G,`+FIC
M<@`N9'EN86UI8P`N9V]T`"YG;W0N<&QT`"YD871A`"YB<W,`+F-O;6UE;G0`
M```````````````````````````````````````````````````````+````
M`0````(````T@00(-`$``!,```````````````$`````````$P````<````"
M````2($$"$@!```@```````````````$`````````"$````'`````@```&B!
M!`AH`0``)```````````````!``````````X````!0````(```",@00(C`$`
M`%P#```&``````````0````$````-````/;__V\"````Z(0$".@$``!8`0``
M!@`````````$````!````#X````+`````@```$"&!`A`!@``0`<```<````!
M````!````!````!&`````P````(```"`C00(@`T```0&``````````````$`
M````````3@```/___V\"````A),$"(03``#H````!@`````````"`````@``
M`%L```#^__]O`@```&R4!`AL%```H`````<````"````!`````````!J````
M"0````(````,E00(#!4``!@````&``````````0````(````<P````D````"
M````))4$""05``"``@``!@````T````$````"````'P````!````!@```*27
M!`BD%P``,```````````````!`````````!W`````0````8```#4EP0(U!<`
M`!`%``````````````0````$````@@````$````&````\)P$"/`<```,,0``
M```````````0`````````(@````!````!@```/S-!`C\30``'```````````
M````!`````````".`````0````(````@S@0(($X``)I>`````````````"``
M````````E@````$````"````O"P%"+RL```$```````````````$````````
M`*`````!`````P```.0^!0CDK@``"```````````````!`````````"G````
M`0````,```#L/@4([*X```@```````````````0`````````K@````$````#
M````]#X%"/2N```$```````````````$`````````+,````&`````P```/@^
M!0CXK@``^`````<`````````!`````@```"\`````0````,```#P/P4(\*\`
M``0```````````````0````$````P0````$````#````]#\%"/2O``!,`0``
M```````````$````!````,H````!`````P```$!!!0A`L0``%```````````
M````!`````````#0````"`````,```!@004(5+$``%`0`````````````"``
M````````U0````$````P`````````%2Q```Y```````````````!`````0``
I``$````#``````````````"-L0``W@```````````````0``````````
